@@ -146,36 +146,13 @@ DESCRIPTION
 .#define bfd_mach_h8300h  2
 .#define bfd_mach_h8300s  3
 .  bfd_arch_powerpc,   {* PowerPC *}
-.#define bfd_mach_ppc		0
-.#define bfd_mach_ppc_403	403
-.#define bfd_mach_ppc_403gc	4030
-.#define bfd_mach_ppc_505	505
-.#define bfd_mach_ppc_601	601
-.#define bfd_mach_ppc_602	602
-.#define bfd_mach_ppc_603	603
-.#define bfd_mach_ppc_ec603e	6031
-.#define bfd_mach_ppc_604	604
-.#define bfd_mach_ppc_620	620
-.#define bfd_mach_ppc_630	630
-.#define bfd_mach_ppc_750	750
-.#define bfd_mach_ppc_860	860
-.#define bfd_mach_ppc_a35	35
-.#define bfd_mach_ppc_rs64ii	642
-.#define bfd_mach_ppc_rs64iii	643
-.#define bfd_mach_ppc_7400	7400
 .  bfd_arch_rs6000,    {* IBM RS/6000 *}
-.#define bfd_mach_rs6k		0
-.#define bfd_mach_rs6k_rs1	6001
-.#define bfd_mach_rs6k_rsc	6003
-.#define bfd_mach_rs6k_rs2	6002
 .  bfd_arch_hppa,      {* HP PA RISC *}
 .  bfd_arch_d10v,      {* Mitsubishi D10V *}
 .#define bfd_mach_d10v		0
 .#define bfd_mach_d10v_ts2	2
 .#define bfd_mach_d10v_ts3	3
 .  bfd_arch_d30v,      {* Mitsubishi D30V *}
-.  bfd_arch_m68hc11,   {* Motorola 68HC11 *}
-.  bfd_arch_m68hc12,   {* Motorola 68HC12 *}
 .  bfd_arch_z8k,       {* Zilog Z8000 *}
 .#define bfd_mach_z8001		1
 .#define bfd_mach_z8002		2
@@ -204,7 +181,6 @@ DESCRIPTION
 .  bfd_arch_ns32k,     {* National Semiconductors ns32000 *}
 .  bfd_arch_w65,       {* WDC 65816 *}
 .  bfd_arch_tic30,     {* Texas Instruments TMS320C30 *}
-.  bfd_arch_tic54x,    {* Texas Instruments TMS320C54X *}
 .  bfd_arch_tic80,     {* TI TMS320c80 (MVP) *}
 .  bfd_arch_v850,      {* NEC V850 *}
 .#define bfd_mach_v850          0
@@ -222,14 +198,12 @@ DESCRIPTION
 .  bfd_arch_fr30,
 .#define bfd_mach_fr30		0x46523330
 .  bfd_arch_mcore,
-.  bfd_arch_ia64,      {* HP/Intel ia64 *}
 .  bfd_arch_pj,
 .  bfd_arch_avr,       {* Atmel AVR microcontrollers *}
 .#define bfd_mach_avr1		1
 .#define bfd_mach_avr2		2
 .#define bfd_mach_avr3		3
 .#define bfd_mach_avr4		4
-.#define bfd_mach_avr5		5
 .  bfd_arch_last
 .  };
 
@@ -282,8 +256,6 @@ extern const bfd_arch_info_type bfd_i386_arch;
 extern const bfd_arch_info_type bfd_i860_arch;
 extern const bfd_arch_info_type bfd_i960_arch;
 extern const bfd_arch_info_type bfd_m32r_arch;
-extern const bfd_arch_info_type bfd_m68hc11_arch;
-extern const bfd_arch_info_type bfd_m68hc12_arch;
 extern const bfd_arch_info_type bfd_m68k_arch;
 extern const bfd_arch_info_type bfd_m88k_arch;
 extern const bfd_arch_info_type bfd_mips_arch;
@@ -295,7 +267,6 @@ extern const bfd_arch_info_type bfd_pj_arch;
 extern const bfd_arch_info_type bfd_sh_arch;
 extern const bfd_arch_info_type bfd_sparc_arch;
 extern const bfd_arch_info_type bfd_tic30_arch;
-extern const bfd_arch_info_type bfd_tic54x_arch;
 extern const bfd_arch_info_type bfd_tic80_arch;
 extern const bfd_arch_info_type bfd_vax_arch;
 extern const bfd_arch_info_type bfd_we32k_arch;
@@ -306,7 +277,6 @@ extern const bfd_arch_info_type bfd_v850_arch;
 extern const bfd_arch_info_type bfd_fr30_arch;
 extern const bfd_arch_info_type bfd_mcore_arch;
 extern const bfd_arch_info_type bfd_avr_arch;
-extern const bfd_arch_info_type bfd_ia64_arch;
 
 static const bfd_arch_info_type * const bfd_archures_list[] =
 {
@@ -327,8 +297,6 @@ static const bfd_arch_info_type * const bfd_archures_list[] =
   &bfd_i860_arch,
   &bfd_i960_arch,
   &bfd_m32r_arch,
-  &bfd_m68hc11_arch,
-  &bfd_m68hc12_arch,
   &bfd_m68k_arch,
   &bfd_m88k_arch,
   &bfd_mips_arch,
@@ -339,7 +307,6 @@ static const bfd_arch_info_type * const bfd_archures_list[] =
   &bfd_sh_arch,
   &bfd_sparc_arch,
   &bfd_tic30_arch,
-  &bfd_tic54x_arch,
   &bfd_tic80_arch,
   &bfd_vax_arch,
   &bfd_we32k_arch,
@@ -350,7 +317,6 @@ static const bfd_arch_info_type * const bfd_archures_list[] =
   &bfd_fr30_arch,
   &bfd_mcore_arch,
   &bfd_avr_arch,
-  &bfd_ia64_arch,
 #endif
   0
 };
