@@ -16,13 +16,13 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "bfd.h"
 #include "sysdep.h"
 #include "libbfd.h"
 
-static bfd_arch_info_type arch_info_struct = 
+const bfd_arch_info_type bfd_vax_arch =
   {
     32,	/* 32 bits in a word */
     32,	/* 32 bits in an address */
@@ -37,9 +37,3 @@ static bfd_arch_info_type arch_info_struct =
     bfd_default_scan ,
     0,
   };
-
-void
-bfd_vax_arch ()
-{
-  bfd_arch_linkin(&arch_info_struct);
-}
