@@ -1,5 +1,5 @@
 /* BFD backend for hp-ux 9000/300
-   Copyright (C) 1990, 1991, 1994, 1995 Free Software Foundation, Inc.
+   Copyright (C) 1990, 91, 94, 95, 97, 99, 2000 Free Software Foundation, Inc.
    Written by Glenn Engel.
 
 This file is part of BFD, the Binary File Descriptor library.
@@ -270,11 +270,8 @@ MY (write_object_contents) (abfd)
   file_ptr text_end;
 
   memset (&exec_bytes, 0, sizeof (exec_bytes));
-#if CHOOSE_RELOC_SIZE
-  CHOOSE_RELOC_SIZE (abfd);
-#else
+
   obj_reloc_entry_size (abfd) = RELOC_STD_SIZE;
-#endif
 
   if (adata (abfd).magic == undecided_magic)
     NAME (aout,adjust_sizes_and_vmas) (abfd, &text_size, &text_end);
@@ -336,9 +333,9 @@ MY (write_object_contents) (abfd)
 
 static void
 convert_sym_type (sym_pointer, cache_ptr, abfd)
-     struct external_nlist *sym_pointer;
+     struct external_nlist *sym_pointer ATTRIBUTE_UNUSED;
      aout_symbol_type *cache_ptr;
-     bfd *abfd;
+     bfd *abfd ATTRIBUTE_UNUSED;
 {
   int name_type;
   int new_type;
@@ -396,7 +393,12 @@ convert_sym_type (sym_pointer, cache_ptr, abfd)
 	    default:
 	      abort ();
 	    case N_UNDF | N_EXT:
-	      new_type = N_WEAKU;
+	      /* If the value is nonzero, then just treat this as a
+                 common symbol.  I don't know if this is correct in
+                 all cases, but it is more correct than treating it as
+                 a weak undefined symbol.  */
+	      if (cache_ptr->symbol.value == 0)
+		new_type = N_WEAKU;
 	      break;
 	    case N_ABS | N_EXT:
 	      new_type = N_WEAKA;
@@ -621,7 +623,7 @@ MY (swap_std_reloc_in) (abfd, bytes, cache_ptr, symbols, symcount)
      struct hp300hpux_reloc *bytes;
      arelent *cache_ptr;
      asymbol **symbols;
-     bfd_size_type symcount;
+     bfd_size_type symcount ATTRIBUTE_UNUSED;
 {
   int r_index;
   int r_extern = 0;
