@@ -256,13 +256,11 @@ static bfd *lineno_cache_bfd;
 static bfd *lineno_cache_rel_bfd;
 
 #define OPTION_TARGET 200
-#define OPTION_DEMANGLER (OPTION_TARGET + 1)
 
 static struct option long_options[] =
 {
   {"debug-syms", no_argument, &print_debug_syms, 1},
-  {"demangle", optional_argument, 0, 'C'},
-  {"demangler", required_argument, NULL, OPTION_DEMANGLER},
+  {"demangle", no_argument, &do_demangle, 1},
   {"dynamic", no_argument, &dynamic, 1},
   {"extern-only", no_argument, &external_only, 1},
   {"format", required_argument, 0, 'f'},
@@ -299,11 +297,8 @@ usage (stream, status)
   -a, --debug-syms       Display debugger-only symbols\n\
   -A, --print-file-name  Print name of the input file before every symbol\n\
   -B                     Same as --format=bsd\n\
-  -C, --demangle[=%s]\n\
-                         Decode low-level symbol names into user-level names\n\
+  -C, --demangle         Decode low-level symbol names into user-level names\n\
       --no-demangle      Do not demangle low-level symbol names\n\
-      --demangler=<dso:function>\n\
-			 Set dso and demangler function\n\
   -D, --dynamic          Display dynamic symbols instead of normal symbols\n\
       --defined-only     Display only defined symbols\n\
   -e                     (ignored)\n\
@@ -324,7 +319,7 @@ usage (stream, status)
       --target=BFDNAME   Specify the target object format as BFDNAME\n\
   -u, --undefined-only   Display only undefined symbols\n\
   -V, --version          Display this program's version number\n\
-\n"), get_demangler_list ());
+\n"));
   list_supported_targets (program_name, stream);
   if (status == 0)
     fprintf (stream, _("Report bugs to %s.\n"), REPORT_BUGS_TO);
@@ -397,7 +392,6 @@ main (argc, argv)
 {
   int c;
   int retval;
-  const char *demangler = NULL, *style = NULL;
 
 #if defined (HAVE_SETLOCALE) && defined (HAVE_LC_MESSAGES)
   setlocale (LC_MESSAGES, "");
@@ -413,8 +407,7 @@ main (argc, argv)
   bfd_init ();
   set_default_bfd_target ();
 
-  while ((c = getopt_long (argc, argv, "aABCDef:glnopPrst:uvV",
-			   long_options, (int *) 0)) != EOF)
+  while ((c = getopt_long (argc, argv, "aABCDef:glnopPrst:uvV", long_options, (int *) 0)) != EOF)
     {
       switch (c)
 	{
@@ -430,8 +423,6 @@ main (argc, argv)
 	  break;
 	case 'C':
 	  do_demangle = 1;
-	  if (optarg != NULL)
-	    style = optarg;
 	  break;
 	case 'D':
 	  dynamic = 1;
@@ -480,10 +471,6 @@ main (argc, argv)
 	  target = optarg;
 	  break;
 
-	case OPTION_DEMANGLER:
-	  demangler = optarg;
-	  break;
-
 	case 0:		/* A long option that just sets a flag.  */
 	  break;
 
@@ -492,8 +479,6 @@ main (argc, argv)
 	}
     }
 
-  init_demangler (style, NULL, demangler);
-
   if (show_version)
     print_version ("nm");
 
@@ -1070,7 +1055,7 @@ print_symname (format, name, abfd)
       if (bfd_get_symbol_leading_char (abfd) == name[0])
 	name++;
 
-      res = demangle_symbol (name);
+      res = cplus_demangle (name, DMGL_ANSI | DMGL_PARAMS);
       if (res)
 	{
 	  printf (format, res);
