@@ -55,9 +55,9 @@ relax_align (address, alignment)
 /* calculate the size of the frag chain and create a bfd section
    to contain all of it */
 static void
-size_section (abfd, idx)
-     bfd * abfd;
-     unsigned int idx;
+DEFUN (size_section, (abfd, idx),
+       bfd * abfd AND
+       unsigned int idx)
 {
   asection *sec;
   unsigned int size = 0;
@@ -106,9 +106,9 @@ size_section (abfd, idx)
 
 /* run through a frag chain and write out the data to go with it */
 static void
-fill_section (abfd, idx)
-     bfd * abfd;
-     unsigned int idx;
+DEFUN (fill_section, (abfd, idx),
+       bfd * abfd AND
+       unsigned int idx)
 {
   asection *sec = segment_info[idx].user_stuff;
   if (sec)
@@ -159,8 +159,8 @@ fill_section (abfd, idx)
 /* Count the relocations in a chain */
 
 static unsigned int
-count_entries_in_chain (idx)
-     unsigned int idx;
+DEFUN (count_entries_in_chain, (idx),
+       unsigned int idx)
 {
   unsigned int nrelocs;
   fixS *fixup_ptr;
@@ -178,8 +178,8 @@ count_entries_in_chain (idx)
 
 /* output all the relocations for a section */
 void
-do_relocs_for (idx)
-     unsigned int idx;
+DEFUN (do_relocs_for, (idx),
+       unsigned int idx)
 {
   unsigned int nrelocs;
   arelent **reloc_ptr_vector;
@@ -270,8 +270,8 @@ do_relocs_for (idx)
 
 /* do the symbols.. */
 static void
-do_symbols (abfd)
-     bfd * abfd;
+DEFUN (do_symbols, (abfd),
+       bfd * abfd)
 {
   extern symbolS *symbol_rootP;
   symbolS *ptr;
@@ -333,7 +333,7 @@ do_symbols (abfd)
    code */
 
 void
-bfd_as_write_hook ()
+DEFUN_VOID (bfd_as_write_hook)
 {
   int i;
 
@@ -509,7 +509,7 @@ obj_symbol_new_hook (symbolP)
 
 #if 1
 extern void
-write_object_file ()
+DEFUN_VOID (write_object_file)
 {
   int i;
   struct frchain *frchain_ptr;
