@@ -66,7 +66,7 @@ const char comment_chars[] = "!/";	/* JF removed '|' from comment_chars */
 /* Also note that comments like this one will always work. */
 const char line_comment_chars[] = "#/";
 
-const char line_separator_chars[] = ";";
+const char line_separator_chars[] = "";
 
 /* Chars that can be used to separate mant from exp in floating point nums */
 const char EXP_CHARS[] = "eE";
