@@ -18,7 +18,10 @@
    the Free Software Foundation, 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.  */
 
-/* Written By Steve Chamberlain <sac@cygnus.com>  */
+/*
+   Written By Steve Chamberlain
+   sac@cygnus.com
+ */
 
 #include <stdio.h>
 #include "as.h"
@@ -27,7 +30,6 @@
 #define DEFINE_TABLE
 #include "opcodes/sh-opc.h"
 #include <ctype.h>
-#include "struc-symbol.h"
 
 #ifdef OBJ_ELF
 #include "elf/sh.h"
@@ -52,7 +54,7 @@ int shl = 0;
 
 static void
 little (ignore)
-     int ignore ATTRIBUTE_UNUSED;
+     int ignore;
 {
   shl = 1;
   target_big_endian = 0;
@@ -62,7 +64,8 @@ little (ignore)
    has to support.  The fields are:
    pseudo-op name without dot
    function to call to execute this pseudo-op
-   Integer arg to pass to the function.  */
+   Integer arg to pass to the function
+ */
 
 const pseudo_typeS md_pseudo_table[] =
 {
@@ -98,7 +101,7 @@ static int valid_arch;
 
 const char EXP_CHARS[] = "eE";
 
-/* Chars that mean this number is a floating point constant.  */
+/* Chars that mean this number is a floating point constant */
 /* As in 0f12.456 */
 /* or    0d1.2345e12 */
 const char FLT_CHARS[] = "rRsSfFdDxXpP";
@@ -109,7 +112,7 @@ const char FLT_CHARS[] = "rRsSfFdDxXpP";
 #define ENCODE_RELAX(what,length) (((what) << 4) + (length))
 #define GET_WHAT(x) ((x>>4))
 
-/* These are the three types of relaxable instrction.  */
+/* These are the three types of relaxable instrction */
 #define COND_JUMP 1
 #define COND_JUMP_DELAY 2
 #define UNCOND_JUMP  3
@@ -156,47 +159,45 @@ const char FLT_CHARS[] = "rRsSfFdDxXpP";
 #define UNCOND32_M -(1<<30)
 #define UNCOND32_LENGTH 14
 
-#define EMPTY { 0, 0, 0, 0 }
-
 const relax_typeS md_relax_table[C (END, 0)] = {
-  EMPTY, EMPTY, EMPTY, EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
-  EMPTY, EMPTY, EMPTY, EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+  { 0 }, { 0 }, { 0 }, { 0 }, { 0 }, { 0 }, { 0 }, { 0 },
+  { 0 }, { 0 }, { 0 }, { 0 }, { 0 }, { 0 }, { 0 }, { 0 },
 
-  EMPTY,
+  { 0 },
   /* C (COND_JUMP, COND8) */
   { COND8_F, COND8_M, COND8_LENGTH, C (COND_JUMP, COND12) },
   /* C (COND_JUMP, COND12) */
   { COND12_F, COND12_M, COND12_LENGTH, C (COND_JUMP, COND32), },
   /* C (COND_JUMP, COND32) */
   { COND32_F, COND32_M, COND32_LENGTH, 0, },
-  EMPTY, EMPTY, EMPTY, EMPTY,
-  EMPTY, EMPTY, EMPTY, EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+  { 0 }, { 0 }, { 0 }, { 0 },
+  { 0 }, { 0 }, { 0 }, { 0 }, { 0 }, { 0 }, { 0 }, { 0 },
 
-  EMPTY,
+  { 0 },
   /* C (COND_JUMP_DELAY, COND8) */
   { COND8_F, COND8_M, COND8_LENGTH, C (COND_JUMP_DELAY, COND12) },
   /* C (COND_JUMP_DELAY, COND12) */
   { COND12_F, COND12_M, COND12_DELAY_LENGTH, C (COND_JUMP_DELAY, COND32), },
   /* C (COND_JUMP_DELAY, COND32) */
   { COND32_F, COND32_M, COND32_LENGTH, 0, },
-  EMPTY, EMPTY, EMPTY, EMPTY,
-  EMPTY, EMPTY, EMPTY, EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+  { 0 }, { 0 }, { 0 }, { 0 },
+  { 0 }, { 0 }, { 0 }, { 0 }, { 0 }, { 0 }, { 0 }, { 0 },
 
-  EMPTY,
+  { 0 },
   /* C (UNCOND_JUMP, UNCOND12) */
   { UNCOND12_F, UNCOND12_M, UNCOND12_LENGTH, C (UNCOND_JUMP, UNCOND32), },
   /* C (UNCOND_JUMP, UNCOND32) */
   { UNCOND32_F, UNCOND32_M, UNCOND32_LENGTH, 0, },
-  EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
-  EMPTY, EMPTY, EMPTY, EMPTY, EMPTY, EMPTY, EMPTY, EMPTY,
+  { 0 }, { 0 }, { 0 }, { 0 }, { 0 },
+  { 0 }, { 0 }, { 0 }, { 0 }, { 0 }, { 0 }, { 0 }, { 0 },
 };
 
-#undef EMPTY
-
 static struct hash_control *opcode_hash_control;	/* Opcode mnemonics */
 
-/* This function is called once, at assembler startup time.  This should
-   set up all the tables, etc that the MD part of the assembler needs.  */
+/*
+   This function is called once, at assembler startup time.  This should
+   set up all the tables, etc that the MD part of the assembler needs
+ */
 
 void
 md_begin ()
@@ -218,7 +219,7 @@ md_begin ()
 
   opcode_hash_control = hash_new ();
 
-  /* Insert unique names into hash table.  */
+  /* Insert unique names into hash table */
   for (opcode = sh_table; opcode->name; opcode++)
     {
       if (strcmp (prev_name, opcode->name))
@@ -231,7 +232,7 @@ md_begin ()
       else
 	{
 	  /* Make all the opcodes with the same name point to the same
-	     string.  */
+	     string */
 	  opcode->name = prev_name;
 	}
     }
@@ -243,18 +244,19 @@ static int reg_x, reg_y;
 static int reg_efg;
 static int reg_b;
 
+static expressionS immediate;	/* absolute expression */
+
 typedef struct
   {
     sh_arg_type type;
     int reg;
-    expressionS immediate;
   }
+
 sh_operand_info;
 
 #define IDENT_CHAR(c) (isalnum (c) || (c) == '_')
 
-/* Try to parse a reg name.  Return the number of chars consumed.  */
-
+/* try and parse a reg name, returns number of chars consumed */
 static int
 parse_reg (src, mode, reg)
      char *src;
@@ -464,9 +466,7 @@ parse_reg (src, mode, reg)
     }
   if (src[0] == 'p' && src[1] == 'c' && ! IDENT_CHAR ((unsigned char) src[2]))
     {
-      /* Don't use A_DISP_PC here - that would accept stuff like 'mova pc,r0'
-         and use an uninitialized immediate.  */
-      *mode = A_PC;
+      *mode = A_DISP_PC;
       return 2;
     }
   if (src[0] == 'g' && src[1] == 'b' && src[2] == 'r'
@@ -602,8 +602,7 @@ parse_reg (src, mode, reg)
   return 0;
 }
 
-static symbolS *
-dot ()
+static symbolS *dot()
 {
   const char *fake;
 
@@ -614,26 +613,29 @@ dot ()
 		      now_seg,
 		      (valueT) frag_now_fix (),
 		      frag_now);
+
 }
 
-static char *
-parse_exp (s, op)
+
+static
+char *
+parse_exp (s)
      char *s;
-     sh_operand_info *op;
 {
   char *save;
   char *new;
 
   save = input_line_pointer;
   input_line_pointer = s;
-  expression (&op->immediate);
-  if (op->immediate.X_op == O_absent)
+  expression (&immediate);
+  if (immediate.X_op == O_absent)
     as_bad (_("missing operand"));
   new = input_line_pointer;
   input_line_pointer = save;
   return new;
 }
 
+
 /* The many forms of operand:
 
    Rn                   Register direct
@@ -651,9 +653,11 @@ parse_exp (s, op)
    disp:12
    #imm8
    pr, gbr, vbr, macl, mach
+
  */
 
-static char *
+static
+char *
 parse_at (src, op)
      char *src;
      sh_operand_info *op;
@@ -663,7 +667,7 @@ parse_at (src, op)
   src++;
   if (src[0] == '-')
     {
-      /* Must be predecrement.  */
+      /* Must be predecrement */
       src++;
 
       len = parse_reg (src, &mode, &(op->reg));
@@ -706,7 +710,7 @@ parse_at (src, op)
       else
 	{
 	  /* Must be an @(disp,.. thing) */
-	  src = parse_exp (src, op);
+	  src = parse_exp (src);
 	  if (src[0] == ',')
 	    src++;
 	  /* Now can be rn, gbr or pc */
@@ -721,14 +725,13 @@ parse_at (src, op)
 		{
 		  op->type = A_DISP_GBR;
 		}
-	      else if (mode == A_PC)
+	      else if (mode == A_DISP_PC)
 		{
-		  /* Turn a plain @(4,pc) into @(.+4,pc).  */
-		  if (op->immediate.X_op == O_constant)
-		    {
-		      op->immediate.X_add_symbol = dot();
-		      op->immediate.X_op = O_symbol;
-		    }
+		  /* Turn a plain @(4,pc) into @(.+4,pc) */
+		  if (immediate.X_op == O_constant) { 
+		    immediate.X_add_symbol = dot();
+		    immediate.X_op = O_symbol;
+		  }
 		  op->type = A_DISP_PC;
 		}
 	      else
@@ -792,7 +795,7 @@ get_operand (ptr, op)
   if (src[0] == '#')
     {
       src++;
-      *ptr = parse_exp (src, op);
+      *ptr = parse_exp (src);
       op->type = A_IMM;
       return;
     }
@@ -811,18 +814,20 @@ get_operand (ptr, op)
     }
   else
     {
-      /* Not a reg, the only thing left is a displacement.  */
-      *ptr = parse_exp (src, op);
+      /* Not a reg, the only thing left is a displacement */
+      *ptr = parse_exp (src);
       op->type = A_DISP_PC;
       return;
     }
 }
 
-static char *
+static
+char *
 get_operands (info, args, operand)
      sh_opcode_info *info;
      char *args;
      sh_operand_info *operand;
+
 {
   char *ptr = args;
   if (info->arg[0])
@@ -841,13 +846,7 @@ get_operands (info, args, operand)
 	      ptr++;
 	    }
 	  get_operand (&ptr, operand + 1);
-	  /* ??? Hack: psha/pshl have a varying operand number depending on
-	     the type of the first operand.  We handle this by having the
-	     three-operand version first and reducing the number of operands
-	     parsed to two if we see that the first operand is an immediate.
-             This works because no insn with three operands has an immediate
-	     as first operand.  */
-	  if (info->arg[2] && operand[0].type != A_IMM)
+	  if (info->arg[2])
 	    {
 	      if (*ptr == ',')
 		{
@@ -877,9 +876,11 @@ get_operands (info, args, operand)
 
 /* Passed a pointer to a list of opcodes which use different
    addressing modes, return the opcode which matches the opcodes
-   provided.  */
+   provided
+ */
 
-static sh_opcode_info *
+static
+sh_opcode_info *
 get_specific (opcode, operands)
      sh_opcode_info *opcode;
      sh_operand_info *operands;
@@ -887,26 +888,24 @@ get_specific (opcode, operands)
   sh_opcode_info *this_try = opcode;
   char *name = opcode->name;
   int n = 0;
-
   while (opcode->name)
     {
       this_try = opcode++;
       if (this_try->name != name)
 	{
 	  /* We've looked so far down the table that we've run out of
-	     opcodes with the same name.  */
+	     opcodes with the same name */
 	  return 0;
 	}
-
-      /* Look at both operands needed by the opcodes and provided by
+      /* look at both operands needed by the opcodes and provided by
          the user - since an arg test will often fail on the same arg
          again and again, we'll try and test the last failing arg the
-         first on each opcode try.  */
+         first on each opcode try */
+
       for (n = 0; this_try->arg[n]; n++)
 	{
 	  sh_operand_info *user = operands + n;
 	  sh_arg_type arg = this_try->arg[n];
-
 	  switch (arg)
 	    {
 	    case A_IMM:
@@ -974,7 +973,7 @@ get_specific (opcode, operands)
 		goto fail;
 	      break;
 
-	    case A_REG_B:
+            case A_REG_B:
 	      if (user->type != arg)
 		goto fail;
 	      reg_b = user->reg;
@@ -1145,7 +1144,7 @@ get_specific (opcode, operands)
 		goto fail;
 	      reg_m = 4;
 	      break;
-
+	
 	    default:
 	      printf (_("unhandled %d\n"), arg);
 	      goto fail;
@@ -1155,8 +1154,7 @@ get_specific (opcode, operands)
 	goto fail;
       valid_arch &= this_try->arch;
       return this_try;
-    fail:
-      ;
+    fail:;
     }
 
   return 0;
@@ -1177,25 +1175,24 @@ check (operand, low, high)
   return operand->X_add_number;
 }
 
+
 static void
-insert (where, how, pcrel, op)
+insert (where, how, pcrel)
      char *where;
      int how;
      int pcrel;
-     sh_operand_info *op;
 {
   fix_new_exp (frag_now,
 	       where - frag_now->fr_literal,
 	       2,
-	       &op->immediate,
+	       &immediate,
 	       pcrel,
 	       how);
 }
 
 static void
-build_relax (opcode, op)
+build_relax (opcode)
      sh_opcode_info *opcode;
-     sh_operand_info *op;
 {
   int high_byte = target_big_endian ? 0 : 1;
   char *p;
@@ -1207,8 +1204,8 @@ build_relax (opcode, op)
 		    md_relax_table[C (what, COND32)].rlx_length,
 		    md_relax_table[C (what, COND8)].rlx_length,
 		    C (what, 0),
-		    op->immediate.X_add_symbol,
-		    op->immediate.X_add_number,
+		    immediate.X_add_symbol,
+		    immediate.X_add_number,
 		    0);
       p[high_byte] = (opcode->nibbles[0] << 4) | (opcode->nibbles[1]);
     }
@@ -1218,66 +1215,16 @@ build_relax (opcode, op)
 		    md_relax_table[C (UNCOND_JUMP, UNCOND32)].rlx_length,
 		    md_relax_table[C (UNCOND_JUMP, UNCOND12)].rlx_length,
 		    C (UNCOND_JUMP, 0),
-		    op->immediate.X_add_symbol,
-		    op->immediate.X_add_number,
+		    immediate.X_add_symbol,
+		    immediate.X_add_number,
 		    0);
       p[high_byte] = (opcode->nibbles[0] << 4);
     }
 
 }
 
-/* Insert ldrs & ldre with fancy relocations that relaxation can recognize.  */
-
-static char *
-insert_loop_bounds (output, operand)
-     char *output;
-     sh_operand_info *operand;
-{
-  char *name;
-  symbolS *end_sym;
-
-  /* Since the low byte of the opcode will be overwritten by the reloc, we
-     can just stash the high byte into both bytes and ignore endianness.  */
-  output[0] = 0x8c;
-  output[1] = 0x8c;
-  insert (output, BFD_RELOC_SH_LOOP_START, 1, operand);
-  insert (output, BFD_RELOC_SH_LOOP_END, 1, operand + 1);
-
-  if (sh_relax)
-    {
-      static int count = 0;
-
-      /* If the last loop insn is a two-byte-insn, it is in danger of being
-	 swapped with the insn after it.  To prevent this, create a new
-	 symbol - complete with SH_LABEL reloc - after the last loop insn.
-	 If the last loop insn is four bytes long, the symbol will be
-	 right in the middle, but four byte insns are not swapped anyways.  */
-      /* A REPEAT takes 6 bytes.  The SH has a 32 bit address space.
-	 Hence a 9 digit number should be enough to count all REPEATs.  */
-      name = alloca (11);
-      sprintf (name, "_R%x", count++ & 0x3fffffff);
-      end_sym = symbol_new (name, undefined_section, 0, &zero_address_frag);
-      /* Make this a local symbol.  */
-#ifdef OBJ_COFF
-      SF_SET_LOCAL (end_sym);
-#endif /* OBJ_COFF */
-      symbol_table_insert (end_sym);
-      end_sym->sy_value = operand[1].immediate;
-      end_sym->sy_value.X_add_number += 2;
-      fix_new (frag_now, frag_now_fix (), 2, end_sym, 0, 1, BFD_RELOC_SH_LABEL);
-    }
-
-  output = frag_more (2);
-  output[0] = 0x8e;
-  output[1] = 0x8e;
-  insert (output, BFD_RELOC_SH_LOOP_START, 1, operand);
-  insert (output, BFD_RELOC_SH_LOOP_END, 1, operand + 1);
-
-  return frag_more (2);
-}
-
-/* Now we know what sort of opcodes it is, let's build the bytes.  */
-
+/* Now we know what sort of opcodes it is, lets build the bytes -
+ */
 static void
 build_Mytes (opcode, operand)
      sh_opcode_info *opcode;
@@ -1318,71 +1265,49 @@ build_Mytes (opcode, operand)
 	    case REG_NM:
 	      nbuf[index] = reg_n | (reg_m >> 2);
 	      break;
-	    case REG_B:
+            case REG_B:
 	      nbuf[index] = reg_b | 0x08;
 	      break;
-	    case IMM0_4BY4:
-	      insert (output + low_byte, BFD_RELOC_SH_IMM4BY4, 0, operand);
+	    case DISP_4:
+	      insert (output + low_byte, BFD_RELOC_SH_IMM4, 0);
 	      break;
-	    case IMM0_4BY2:
-	      insert (output + low_byte, BFD_RELOC_SH_IMM4BY2, 0, operand);
+	    case IMM_4BY4:
+	      insert (output + low_byte, BFD_RELOC_SH_IMM4BY4, 0);
 	      break;
-	    case IMM0_4:
-	      insert (output + low_byte, BFD_RELOC_SH_IMM4, 0, operand);
+	    case IMM_4BY2:
+	      insert (output + low_byte, BFD_RELOC_SH_IMM4BY2, 0);
 	      break;
-	    case IMM1_4BY4:
-	      insert (output + low_byte, BFD_RELOC_SH_IMM4BY4, 0, operand + 1);
+	    case IMM_4:
+	      insert (output + low_byte, BFD_RELOC_SH_IMM4, 0);
 	      break;
-	    case IMM1_4BY2:
-	      insert (output + low_byte, BFD_RELOC_SH_IMM4BY2, 0, operand + 1);
+	    case IMM_8BY4:
+	      insert (output + low_byte, BFD_RELOC_SH_IMM8BY4, 0);
 	      break;
-	    case IMM1_4:
-	      insert (output + low_byte, BFD_RELOC_SH_IMM4, 0, operand + 1);
+	    case IMM_8BY2:
+	      insert (output + low_byte, BFD_RELOC_SH_IMM8BY2, 0);
 	      break;
-	    case IMM0_8BY4:
-	      insert (output + low_byte, BFD_RELOC_SH_IMM8BY4, 0, operand);
-	      break;
-	    case IMM0_8BY2:
-	      insert (output + low_byte, BFD_RELOC_SH_IMM8BY2, 0, operand);
-	      break;
-	    case IMM0_8:
-	      insert (output + low_byte, BFD_RELOC_SH_IMM8, 0, operand);
-	      break;
-	    case IMM1_8BY4:
-	      insert (output + low_byte, BFD_RELOC_SH_IMM8BY4, 0, operand + 1);
-	      break;
-	    case IMM1_8BY2:
-	      insert (output + low_byte, BFD_RELOC_SH_IMM8BY2, 0, operand + 1);
-	      break;
-	    case IMM1_8:
-	      insert (output + low_byte, BFD_RELOC_SH_IMM8, 0, operand + 1);
+	    case IMM_8:
+	      insert (output + low_byte, BFD_RELOC_SH_IMM8, 0);
 	      break;
 	    case PCRELIMM_8BY4:
-	      insert (output, BFD_RELOC_SH_PCRELIMM8BY4, 1, operand);
+	      insert (output, BFD_RELOC_SH_PCRELIMM8BY4, 1);
 	      break;
 	    case PCRELIMM_8BY2:
-	      insert (output, BFD_RELOC_SH_PCRELIMM8BY2, 1, operand);
-	      break;
-	    case REPEAT:
-	      output = insert_loop_bounds (output, operand);
-	      nbuf[index] = opcode->nibbles[3];
-	      operand += 2;
+	      insert (output, BFD_RELOC_SH_PCRELIMM8BY2, 1);
 	      break;
 	    default:
 	      printf (_("failed for %d\n"), i);
 	    }
 	}
     }
-  if (!target_big_endian)
-    {
-      output[1] = (nbuf[0] << 4) | (nbuf[1]);
-      output[0] = (nbuf[2] << 4) | (nbuf[3]);
-    }
-  else
-    {
-      output[0] = (nbuf[0] << 4) | (nbuf[1]);
-      output[1] = (nbuf[2] << 4) | (nbuf[3]);
-    }
+  if (! target_big_endian) {
+    output[1] = (nbuf[0] << 4) | (nbuf[1]);
+    output[0] = (nbuf[2] << 4) | (nbuf[3]);
+  }
+  else {
+    output[0] = (nbuf[0] << 4) | (nbuf[1]);
+    output[1] = (nbuf[2] << 4) | (nbuf[3]);
+  }
 }
 
 /* Find an opcode at the start of *STR_P in the hash table, and set
@@ -1397,8 +1322,7 @@ find_cooked_opcode (str_p)
   unsigned char *op_end;
   char name[20];
   int nlen = 0;
-
-  /* Drop leading whitespace.  */
+  /* Drop leading whitespace */
   while (*str == ' ')
     str++;
 
@@ -1423,19 +1347,19 @@ find_cooked_opcode (str_p)
       name[nlen] = c;
       nlen++;
     }
-
   name[nlen] = 0;
   *str_p = op_end;
 
   if (nlen == 0)
-    as_bad (_("can't find opcode "));
+    {
+      as_bad (_("can't find opcode "));
+    }
 
   return (sh_opcode_info *) hash_find (opcode_hash_control, name);
 }
 
 /* Assemble a parallel processing insn.  */
 #define DDT_BASE 0xf000 /* Base value for double data transfer insns */
-
 static void
 assemble_ppi (op_end, opcode)
      char *op_end;
@@ -1462,7 +1386,7 @@ assemble_ppi (op_end, opcode)
       opcode = get_specific (opcode, operand);
       if (opcode == 0)
 	{
-	  /* Couldn't find an opcode which matched the operands.  */
+	  /* Couldn't find an opcode which matched the operands */
 	  char *where = frag_more (2);
 
 	  where[0] = 0x0;
@@ -1470,7 +1394,6 @@ assemble_ppi (op_end, opcode)
 	  as_bad (_("invalid operands for opcode"));
 	  return;
 	}
-
       if (opcode->nibbles[0] != PPI)
 	as_bad (_("insn can't be combined with parallel processing insn"));
 
@@ -1534,10 +1457,10 @@ assemble_ppi (op_end, opcode)
 	  break;
 
 	case PSH:
-	  if (operand[0].immediate.X_op != O_constant)
+	  if (immediate.X_op != O_constant)
 	    as_bad (_("dsp immediate shift value not constant"));
 	  field_b = ((opcode->nibbles[2] << 12)
-		     | (operand[0].immediate.X_add_number & 127) << 4
+		     | (immediate.X_add_number & 127) << 4
 		     | reg_n);
 	  break;
 	case PPI3:
@@ -1642,7 +1565,8 @@ assemble_ppi (op_end, opcode)
 
 /* This is the guts of the machine-dependent assembler.  STR points to a
    machine dependent instruction.  This function is supposed to emit
-   the frags/bytes it assembles to.  */
+   the frags/bytes it assembles to.
+ */
 
 void
 md_assemble (str)
@@ -1680,8 +1604,8 @@ md_assemble (str)
   if (opcode->arg[0] == A_BDISP12
       || opcode->arg[0] == A_BDISP8)
     {
-      parse_exp (op_end + 1, &operand[0]);
-      build_relax (opcode, &operand[0]);
+      parse_exp (op_end + 1);
+      build_relax (opcode);
     }
   else
     {
@@ -1700,7 +1624,7 @@ md_assemble (str)
 
       if (opcode == 0)
 	{
-	  /* Couldn't find an opcode which matched the operands.  */
+	  /* Couldn't find an opcode which matched the operands */
 	  char *where = frag_more (2);
 
 	  where[0] = 0x0;
@@ -1734,7 +1658,7 @@ sh_frob_label ()
       offset = frag_now_fix ();
       if (frag_now != last_label_frag
 	  || offset != last_label_offset)
-	{
+	{	
 	  fix_new (frag_now, offset, 2, &abs_symbol, 0, 0, BFD_RELOC_SH_LABEL);
 	  last_label_frag = frag_now;
 	  last_label_offset = offset;
@@ -1758,8 +1682,8 @@ sh_flush_pending_output ()
 }
 
 symbolS *
-md_undefined_symbol (name)
-     char *name;
+DEFUN (md_undefined_symbol, (name),
+       char *name)
 {
   return 0;
 }
@@ -1768,15 +1692,15 @@ md_undefined_symbol (name)
 #ifndef BFD_ASSEMBLER
 
 void
-tc_crawl_symbol_chain (headers)
-     object_headers *headers;
+DEFUN (tc_crawl_symbol_chain, (headers),
+       object_headers * headers)
 {
   printf (_("call to tc_crawl_symbol_chain \n"));
 }
 
 void
-tc_headers_hook (headers)
-     object_headers *headers;
+DEFUN (tc_headers_hook, (headers),
+       object_headers * headers)
 {
   printf (_("call to tc_headers_hook \n"));
 }
@@ -1784,15 +1708,14 @@ tc_headers_hook (headers)
 #endif
 #endif
 
-/* Various routines to kill one day.  */
-/* Equal to MAX_PRECISION in atof-ieee.c.  */
+/* Various routines to kill one day */
+/* Equal to MAX_PRECISION in atof-ieee.c */
 #define MAX_LITTLENUMS 6
 
-/* Turn a string in input_line_pointer into a floating point constant
-   of type TYPE, and store the appropriate bytes in *LITP.  The number
-   of LITTLENUMS emitted is stored in *SIZEP .  An error message is
-   returned, or NULL on OK.  */
-
+/* Turn a string in input_line_pointer into a floating point constant of type
+   type, and store the appropriate bytes in *litP.  The number of LITTLENUMS
+   emitted is stored in *sizeP .  An error message is returned, or NULL on OK.
+ */
 char *
 md_atof (type, litP, sizeP)
      int type;
@@ -1841,7 +1764,7 @@ md_atof (type, litP, sizeP)
 	  litP += 2;
 	}
     }
-
+     
   return NULL;
 }
 
@@ -1852,7 +1775,7 @@ md_atof (type, litP, sizeP)
 
 static void
 s_uses (ignore)
-     int ignore ATTRIBUTE_UNUSED;
+     int ignore;
 {
   expressionS ex;
 
@@ -1874,8 +1797,8 @@ s_uses (ignore)
 }
 
 CONST char *md_shortopts = "";
-struct option md_longopts[] =
-{
+struct option md_longopts[] = {
+
 #define OPTION_RELAX  (OPTION_MD_BASE)
 #define OPTION_LITTLE (OPTION_MD_BASE + 1)
 #define OPTION_SMALL (OPTION_LITTLE + 1)
@@ -1887,12 +1810,12 @@ struct option md_longopts[] =
   {"dsp", no_argument, NULL, OPTION_DSP},
   {NULL, no_argument, NULL, 0}
 };
-size_t md_longopts_size = sizeof (md_longopts);
+size_t md_longopts_size = sizeof(md_longopts);
 
 int
 md_parse_option (c, arg)
      int c;
-     char *arg ATTRIBUTE_UNUSED;
+     char *arg;
 {
   switch (c)
     {
@@ -1924,7 +1847,7 @@ void
 md_show_usage (stream)
      FILE *stream;
 {
-  fprintf (stream, _("\
+  fprintf(stream, _("\
 SH options:\n\
 -little			generate little endian code\n\
 -relax			alter jump instructions for long displacements\n\
@@ -1954,9 +1877,10 @@ struct sh_count_relocs
    symbol.  When using BFD_ASSEMBLER, this is called via
    bfd_map_over_sections.  */
 
+/*ARGSUSED*/
 static void
 sh_count_relocs (abfd, sec, data)
-     bfd *abfd ATTRIBUTE_UNUSED;
+     bfd *abfd;
      segT sec;
      PTR data;
 {
@@ -1983,11 +1907,12 @@ sh_count_relocs (abfd, sec, data)
 /* Handle the count relocs for a particular section.  When using
    BFD_ASSEMBLER, this is called via bfd_map_over_sections.  */
 
+/*ARGSUSED*/
 static void
 sh_frob_section (abfd, sec, ignore)
-     bfd *abfd ATTRIBUTE_UNUSED;
+     bfd *abfd;
      segT sec;
-     PTR ignore ATTRIBUTE_UNUSED;
+     PTR ignore;
 {
   segment_info_type *seginfo;
   fixS *fix;
@@ -2048,8 +1973,8 @@ sh_frob_section (abfd, sec, ignore)
 	  continue;
 	}
 
-      /* The variable fscan should also be a fixup to a local symbol
-	 in the same section.  */
+      /* fscan should also be a fixup to a local symbol in the same
+	 section.  */
       sym = fscan->fx_addsy;
       if (sym == NULL
 	  || fscan->fx_subsy != NULL
@@ -2127,7 +2052,7 @@ sh_frob_file ()
 void
 md_convert_frag (headers, seg, fragP)
 #ifdef BFD_ASSEMBLER
-     bfd *headers ATTRIBUTE_UNUSED;
+     bfd *headers;
 #else
      object_headers *headers;
 #endif
@@ -2162,16 +2087,15 @@ md_convert_frag (headers, seg, fragP)
 		(unsigned long) fragP->fr_address);
       else if (S_IS_DEFINED (fragP->fr_symbol))
 	as_bad (_("at 0x%lx, displacement to defined symbol %s overflows 12-bit field"),
-		(unsigned long) fragP->fr_address,
+		(unsigned long) fragP->fr_address,		
 		S_GET_NAME (fragP->fr_symbol));
       else
 	as_bad (_("at 0x%lx, displacement to undefined symbol %s overflows 12-bit field"),
-		(unsigned long) fragP->fr_address,
+		(unsigned long) fragP->fr_address,		
 		S_GET_NAME (fragP->fr_symbol));
 
-#if 0
-      /* This code works, but generates poor code and the compiler
-	 should never produce a sequence that requires it to be used.  */
+#if 0				/* This code works, but generates poor code and the compiler
+				   should never produce a sequence that requires it to be used.  */
 
       /* A jump wont fit in 12 bits, make code which looks like
 	 bra foo
@@ -2181,23 +2105,23 @@ md_convert_frag (headers, seg, fragP)
 	 */
       int t = buffer[0] & 0x10;
 
-      buffer[highbyte     ] = 0xa0;	/* branch over move and disp */
-      buffer[lowbyte      ] = 3;
-      buffer[highbyte +  2] = 0xd0 | JREG;	/* Build mov insn */
-      buffer[lowbyte  +  2] = 0x00;
+      buffer[highbyte] = 0xa0;	/* branch over move and disp */
+      buffer[lowbyte] = 3;
+      buffer[highbyte+2] = 0xd0 | JREG;	/* Build mov insn */
+      buffer[lowbyte+2] = 0x00;
 
-      buffer[highbyte +  4] = 0;	/* space for 32 bit jump disp */
-      buffer[lowbyte  +  4] = 0;
-      buffer[highbyte +  6] = 0;
-      buffer[lowbyte  +  6] = 0;
+      buffer[highbyte+4] = 0;	/* space for 32 bit jump disp */
+      buffer[lowbyte+4] = 0;
+      buffer[highbyte+6] = 0;
+      buffer[lowbyte+6] = 0;
 
-      buffer[highbyte +  8] = 0x40 | JREG;	/* Build jmp @JREG */
-      buffer[lowbyte  +  8] = t ? 0xb : 0x2b;
+      buffer[highbyte+8] = 0x40 | JREG;	/* Build jmp @JREG */
+      buffer[lowbyte+8] = t ? 0xb : 0x2b;
 
-      buffer[highbyte + 10] = 0x20; /* build nop */
-      buffer[lowbyte  + 10] = 0x0b;
+      buffer[highbyte+10] = 0x20; /* build nop */
+      buffer[lowbyte+10] = 0x0b;
 
-      /* Make reloc for the long disp.  */
+      /* Make reloc for the long disp */
       fix_new (fragP,
 	       fragP->fr_fix + 4,
 	       4,
@@ -2214,13 +2138,13 @@ md_convert_frag (headers, seg, fragP)
 
     case C (COND_JUMP, COND12):
     case C (COND_JUMP_DELAY, COND12):
-      /* A bcond won't fit, so turn it into a b!cond; bra disp; nop.  */
+      /* A bcond won't fit, so turn it into a b!cond; bra disp; nop */
       /* I found that a relax failure for gcc.c-torture/execute/930628-1.c
 	 was due to gas incorrectly relaxing an out-of-range conditional
 	 branch with delay slot.  It turned:
                      bf.s    L6              (slot mov.l   r12,@(44,r0))
          into:
-
+   
 2c:  8f 01 a0 8b     bf.s    32 <_main+32>   (slot bra       L6)
 30:  00 09           nop
 32:  10 cb           mov.l   r12,@(44,r0)
@@ -2282,20 +2206,19 @@ md_convert_frag (headers, seg, fragP)
     case C (COND_JUMP, UNDEF_WORD_DISP):
     case C (COND_JUMP_DELAY, UNDEF_WORD_DISP):
       if (fragP->fr_symbol == NULL)
-	as_bad (_("at 0x%lx, displacement overflows 8-bit field"),
+	as_bad (_("at 0x%lx, displacement overflows 8-bit field"), 
 		(unsigned long) fragP->fr_address);
       else if (S_IS_DEFINED (fragP->fr_symbol))
 	as_bad (_("at 0x%lx, displacement to defined symbol %s overflows 8-bit field "),
-		(unsigned long) fragP->fr_address,
+		(unsigned long) fragP->fr_address,		
 		S_GET_NAME (fragP->fr_symbol));
       else
 	as_bad (_("at 0x%lx, displacement to undefined symbol %s overflows 8-bit field "),
-		(unsigned long) fragP->fr_address,
+		(unsigned long) fragP->fr_address,		
 		S_GET_NAME (fragP->fr_symbol));
 
-#if 0
-      /* This code works, but generates poor code, and the compiler
-	 should never produce a sequence that requires it to be used.  */
+#if 0				/* This code works, but generates poor code, and the compiler
+				   should never produce a sequence that requires it to be used.  */
 
       /* A bcond won't fit and it won't go into a 12 bit
 	 displacement either, the code sequence looks like:
@@ -2350,9 +2273,9 @@ md_convert_frag (headers, seg, fragP)
 }
 
 valueT
-md_section_align (seg, size)
-     segT seg;
-     valueT size;
+DEFUN (md_section_align, (seg, size),
+       segT seg AND
+       valueT size)
 {
 #ifdef BFD_ASSEMBLER
 #ifdef OBJ_ELF
@@ -2484,9 +2407,7 @@ sh_force_relocation (fix)
 {
 
   if (fix->fx_r_type == BFD_RELOC_VTABLE_INHERIT
-      || fix->fx_r_type == BFD_RELOC_VTABLE_ENTRY
-      || fix->fx_r_type == BFD_RELOC_SH_LOOP_START
-      || fix->fx_r_type == BFD_RELOC_SH_LOOP_END)
+      || fix->fx_r_type == BFD_RELOC_VTABLE_ENTRY)
     return 1;
 
   if (! sh_relax)
@@ -2509,7 +2430,7 @@ sh_fix_adjustable (fixP)
 
   if (fixP->fx_addsy == NULL)
     return 1;
-
+  
   /* We need the symbol name for the VTABLE entries */
   if (fixP->fx_r_type == BFD_RELOC_VTABLE_INHERIT
       || fixP->fx_r_type == BFD_RELOC_VTABLE_ENTRY)
@@ -2518,8 +2439,7 @@ sh_fix_adjustable (fixP)
   return 1;
 }
 
-void
-sh_elf_final_processing ()
+void sh_elf_final_processing()
 {
   int val;
 
@@ -2571,9 +2491,9 @@ md_apply_fix (fixP, val)
   int shift;
 
 #ifdef BFD_ASSEMBLER
-  /* The function adjust_reloc_syms won't convert a reloc against a weak
-     symbol into a reloc against a section, but bfd_install_relocation
-     will screw up if the symbol is defined, so we have to adjust val here
+  /* adjust_reloc_syms won't convert a reloc against a weak symbol
+     into a reloc against a section, but bfd_install_relocation will
+     screw up if the symbol is defined, so we have to adjust val here
      to avoid the screw up later.  */
   if (fixP->fx_addsy != NULL
       && S_IS_WEAK (fixP->fx_addsy))
@@ -2634,7 +2554,7 @@ md_apply_fix (fixP, val)
          Note that adding further restrictions may invalidate
          reasonable looking assembly code, such as ``and -0x1,r0''.  */
       max = 0xff;
-      min = -0xff;
+      min = - 0xff;
       *buf++ = val;
       break;
 
@@ -2681,14 +2601,14 @@ md_apply_fix (fixP, val)
       break;
 
     case BFD_RELOC_32:
-      if (!target_big_endian)
+      if (! target_big_endian) 
 	{
 	  *buf++ = val >> 0;
 	  *buf++ = val >> 8;
 	  *buf++ = val >> 16;
 	  *buf++ = val >> 24;
 	}
-      else
+      else 
 	{
 	  *buf++ = val >> 24;
 	  *buf++ = val >> 16;
@@ -2702,8 +2622,8 @@ md_apply_fix (fixP, val)
 	{
 	  *buf++ = val >> 0;
 	  *buf++ = val >> 8;
-	}
-      else
+	} 
+      else 
 	{
 	  *buf++ = val >> 8;
 	  *buf++ = val >> 0;
@@ -2723,9 +2643,6 @@ md_apply_fix (fixP, val)
       /* Nothing to do here.  */
       break;
 
-    case BFD_RELOC_SH_LOOP_START:
-    case BFD_RELOC_SH_LOOP_END:
-
     case BFD_RELOC_VTABLE_INHERIT:
     case BFD_RELOC_VTABLE_ENTRY:
       fixP->fx_done = 0;
@@ -2768,7 +2685,7 @@ md_estimate_size_before_relax (fragP, segment_type)
   switch (fragP->fr_subtype)
     {
     case C (UNCOND_JUMP, UNDEF_DISP):
-      /* Used to be a branch to somewhere which was unknown.  */
+      /* used to be a branch to somewhere which was unknown */
       if (!fragP->fr_symbol)
 	{
 	  fragP->fr_subtype = C (UNCOND_JUMP, UNCOND12);
@@ -2791,20 +2708,20 @@ md_estimate_size_before_relax (fragP, segment_type)
       abort ();
     case C (COND_JUMP, UNDEF_DISP):
     case C (COND_JUMP_DELAY, UNDEF_DISP):
-      /* Used to be a branch to somewhere which was unknown.  */
+      /* used to be a branch to somewhere which was unknown */
       if (fragP->fr_symbol
 	  && S_GET_SEGMENT (fragP->fr_symbol) == segment_type)
 	{
 	  int what = GET_WHAT (fragP->fr_subtype);
 	  /* Got a symbol and it's defined in this segment, become byte
-	     sized - maybe it will fix up.  */
+	     sized - maybe it will fix up */
 	  fragP->fr_subtype = C (what, COND8);
 	  fragP->fr_var = md_relax_table[C (what, COND8)].rlx_length;
 	}
       else if (fragP->fr_symbol)
 	{
 	  int what = GET_WHAT (fragP->fr_subtype);
-	  /* Its got a segment, but its not ours, so it will always be long.  */
+	  /* Its got a segment, but its not ours, so it will always be long */
 	  fragP->fr_subtype = C (what, UNDEF_WORD_DISP);
 	  fragP->fr_var = md_relax_table[C (what, COND32)].rlx_length;
 	  return md_relax_table[C (what, COND32)].rlx_length;
@@ -2812,7 +2729,7 @@ md_estimate_size_before_relax (fragP, segment_type)
       else
 	{
 	  int what = GET_WHAT (fragP->fr_subtype);
-	  /* We know the abs value.  */
+	  /* We know the abs value */
 	  fragP->fr_subtype = C (what, COND8);
 	  fragP->fr_var = md_relax_table[C (what, COND8)].rlx_length;
 	}
@@ -2822,7 +2739,7 @@ md_estimate_size_before_relax (fragP, segment_type)
   return fragP->fr_var;
 }
 
-/* Put number into target byte order.  */
+/* Put number into target byte order */
 
 void
 md_number_to_chars (ptr, use, nbytes)
@@ -2860,7 +2777,7 @@ int
 sh_do_align (n, fill, len, max)
      int n;
      const char *fill;
-     int len ATTRIBUTE_UNUSED;
+     int len;
      int max;
 {
   if (fill == NULL
@@ -3042,7 +2959,7 @@ sh_coff_reloc_mangle (seg, fix, intr, paddr)
 
 arelent *
 tc_gen_reloc (section, fixp)
-     asection *section ATTRIBUTE_UNUSED;
+     asection *section;
      fixS *fixp;
 {
   arelent *rel;
@@ -3076,14 +2993,6 @@ tc_gen_reloc (section, fixp)
   else if (r_type == BFD_RELOC_VTABLE_INHERIT
            || r_type == BFD_RELOC_VTABLE_ENTRY)
     rel->addend = fixp->fx_offset;
-  else if (r_type == BFD_RELOC_SH_LOOP_START
-           || r_type == BFD_RELOC_SH_LOOP_END)
-    rel->addend = fixp->fx_offset;
-  else if (r_type == BFD_RELOC_SH_LABEL && fixp->fx_pcrel)
-    {
-      rel->addend = 0;
-      rel->address = rel->addend = fixp->fx_offset;
-    }
   else if (fixp->fx_pcrel)
     rel->addend = fixp->fx_addnumber;
   else
