@@ -42,7 +42,7 @@ static boolean warn_unsigned_overflows = FALSE;
 static int     machine = -1;
 
 /* Indicates the target processor(s) for the assemble.  */
-static int	processor_mask = -1;
+static unsigned int	processor_mask = -1;
 
 
 /* Structure to hold information about predefined registers.  */
@@ -112,7 +112,7 @@ static int fc;
 
 
 void
-v850_sdata (int ignore ATTRIBUTE_UNUSED)
+v850_sdata (int ignore)
 {
   obj_elf_section_change_hook();
   
@@ -122,7 +122,7 @@ v850_sdata (int ignore ATTRIBUTE_UNUSED)
 }
 
 void
-v850_tdata (int ignore ATTRIBUTE_UNUSED)
+v850_tdata (int ignore)
 {
   obj_elf_section_change_hook();
   
@@ -132,7 +132,7 @@ v850_tdata (int ignore ATTRIBUTE_UNUSED)
 }
 
 void
-v850_zdata (int ignore ATTRIBUTE_UNUSED)
+v850_zdata (int ignore)
 {
   obj_elf_section_change_hook();
   
@@ -142,7 +142,7 @@ v850_zdata (int ignore ATTRIBUTE_UNUSED)
 }
 
 void
-v850_sbss (int ignore ATTRIBUTE_UNUSED)
+v850_sbss (int ignore)
 {
   obj_elf_section_change_hook();
   
@@ -152,7 +152,7 @@ v850_sbss (int ignore ATTRIBUTE_UNUSED)
 }
 
 void
-v850_tbss (int ignore ATTRIBUTE_UNUSED)
+v850_tbss (int ignore)
 {
   obj_elf_section_change_hook();
   
@@ -162,7 +162,7 @@ v850_tbss (int ignore ATTRIBUTE_UNUSED)
 }
 
 void
-v850_zbss (int ignore ATTRIBUTE_UNUSED)
+v850_zbss (int ignore)
 {
   obj_elf_section_change_hook();
   
@@ -172,7 +172,7 @@ v850_zbss (int ignore ATTRIBUTE_UNUSED)
 }
 
 void
-v850_rosdata (int ignore ATTRIBUTE_UNUSED)
+v850_rosdata (int ignore)
 {
   obj_elf_section_change_hook();
   
@@ -182,7 +182,7 @@ v850_rosdata (int ignore ATTRIBUTE_UNUSED)
 }
 
 void
-v850_rozdata (int ignore ATTRIBUTE_UNUSED)
+v850_rozdata (int ignore)
 {
   obj_elf_section_change_hook();
   
@@ -192,7 +192,7 @@ v850_rozdata (int ignore ATTRIBUTE_UNUSED)
 }
 
 void
-v850_call_table_data (int ignore ATTRIBUTE_UNUSED)
+v850_call_table_data (int ignore)
 {
   obj_elf_section_change_hook();
   
@@ -202,7 +202,7 @@ v850_call_table_data (int ignore ATTRIBUTE_UNUSED)
 }
 
 void
-v850_call_table_text (int ignore ATTRIBUTE_UNUSED)
+v850_call_table_text (int ignore)
 {
   obj_elf_section_change_hook();
   
@@ -212,7 +212,7 @@ v850_call_table_text (int ignore ATTRIBUTE_UNUSED)
 }
 
 void
-v850_bss (int ignore ATTRIBUTE_UNUSED)
+v850_bss (int ignore)
 {
   register int temp = get_absolute_expression ();
 
@@ -224,7 +224,7 @@ v850_bss (int ignore ATTRIBUTE_UNUSED)
 }
 
 void
-v850_offset (int ignore ATTRIBUTE_UNUSED)
+v850_offset (int ignore)
 {
   int temp = get_absolute_expression ();
   
@@ -245,7 +245,7 @@ v850_comm (area)
   char      c;
   char *    p;
   int       temp;
-  unsigned int       size;
+  int       size;
   symbolS * symbolP;
   int       have_align;
 
@@ -484,10 +484,9 @@ v850_comm (area)
 		  
 		  scommon_section = subseg_new (".scommon", 0);
 		  
-		  bfd_set_section_flags (stdoutput, scommon_section,
-					 (applicable
+		  bfd_set_section_flags (stdoutput, scommon_section, applicable
 		     & (SEC_ALLOC | SEC_LOAD | SEC_RELOC | SEC_DATA
-			| SEC_HAS_CONTENTS)) | SEC_IS_COMMON);
+			| SEC_HAS_CONTENTS) | SEC_IS_COMMON);
 		}
 	      S_SET_SEGMENT (symbolP, scommon_section);
 	      break;
@@ -501,10 +500,9 @@ v850_comm (area)
 		  
 		  zcommon_section = subseg_new (".zcommon", 0);
 		  
-		  bfd_set_section_flags (stdoutput, zcommon_section,
-					 (applicable
+		  bfd_set_section_flags (stdoutput, zcommon_section, applicable
 		     & (SEC_ALLOC | SEC_LOAD | SEC_RELOC | SEC_DATA
-			| SEC_HAS_CONTENTS)) | SEC_IS_COMMON);
+			| SEC_HAS_CONTENTS) | SEC_IS_COMMON);
 		}
 	      S_SET_SEGMENT (symbolP, zcommon_section);
 	      break;
@@ -518,10 +516,9 @@ v850_comm (area)
 		  
 		  tcommon_section = subseg_new (".tcommon", 0);
 		  
-		  bfd_set_section_flags (stdoutput, tcommon_section,
-					 (applicable
+		  bfd_set_section_flags (stdoutput, tcommon_section, applicable
 		     & (SEC_ALLOC | SEC_LOAD | SEC_RELOC | SEC_DATA
-			| SEC_HAS_CONTENTS)) | SEC_IS_COMMON);
+			| SEC_HAS_CONTENTS) | SEC_IS_COMMON);
 		}
 	      S_SET_SEGMENT (symbolP, tcommon_section);
 	      break;
@@ -858,9 +855,10 @@ system_register_name (expressionP, accept_numbers, accept_list_names)
 
 	  /* Make sure that the register number is allowable. */
 	  if (   reg_number < 0
-	      || (reg_number > 5 && reg_number < 16)
-	      || reg_number > 20
-	      )
+		 || reg_number > 5
+		 && reg_number < 16
+		 || reg_number > 20
+		 )
 	    {
 	      reg_number = -1;
 	    }
@@ -1011,6 +1009,7 @@ parse_register_list
   
   if (* input_line_pointer != '{')
     {
+      int bits;
       int reg;
       int i;
 		
@@ -1201,9 +1200,8 @@ md_parse_option (c, arg)
 {
   if (c != 'm')
     {
-      if (c != 'a')
-	/* xgettext:c-format */
-	fprintf (stderr, _("unknown command line option: -%c%s\n"), c, arg);
+      /* xgettext:c-format */
+      fprintf (stderr, _("unknown command line option: -%c%s\n"), c, arg);
       return 0;
     }
 
@@ -1247,7 +1245,7 @@ md_parse_option (c, arg)
 
 symbolS *
 md_undefined_symbol (name)
-  char * name ATTRIBUTE_UNUSED;
+  char * name;
 {
   return 0;
 }
@@ -1297,7 +1295,7 @@ md_atof (type, litp, sizep)
 /* Very gross.  */
 void
 md_convert_frag (abfd, sec, fragP)
-  bfd *      abfd ATTRIBUTE_UNUSED;
+  bfd *      abfd;
   asection * sec;
   fragS *    fragP;
 {
@@ -1592,7 +1590,8 @@ v850_insert_operand (insn, operand, val, file, line, str)
     {
       if (operand->bits != 32)
 	{
-	  long  min, max;
+	  long    min, max;
+	  offsetT test;
 
 	  if ((operand->flags & V850_OPERAND_SIGNED) != 0)
 	    {
@@ -1663,15 +1662,15 @@ md_assemble (str)
   struct v850_opcode *      next_opcode;
   const unsigned char *     opindex_ptr;
   int                       next_opindex;
-  int                       relaxable = 0;
+  int                       relaxable;
   unsigned long             insn;
   unsigned long             insn_size;
   char *                    f;
   int                       i;
   int                       match;
   boolean                   extra_data_after_insn = false;
-  unsigned                  extra_data_len = 0;
-  unsigned long             extra_data = 0;
+  unsigned                  extra_data_len;
+  unsigned long             extra_data;
   char *		    saved_input_line_pointer;
 
   
@@ -2214,8 +2213,6 @@ md_assemble (str)
 	    case BFD_RELOC_HI16_S:
 	      fixP->fx_no_overflow = 1;
 	      break;
-	    default:
-	      break;
 	    }
 	}
       else
@@ -2240,7 +2237,7 @@ md_assemble (str)
                  
 arelent *
 tc_gen_reloc (seg, fixp)
-     asection * seg ATTRIBUTE_UNUSED;
+     asection * seg;
      fixS *     fixp;
 {
   arelent * reloc;
@@ -2276,7 +2273,7 @@ tc_gen_reloc (seg, fixp)
 int
 md_estimate_size_before_relax (fragp, seg)
      fragS * fragp;
-     asection * seg ATTRIBUTE_UNUSED;
+     asection * seg;
 {
   if (fragp->fr_subtype == 0)
     fragp->fr_var = 4;
@@ -2308,7 +2305,7 @@ int
 md_apply_fix3 (fixp, valuep, seg)
      fixS *   fixp;
      valueT * valuep;
-     segT     seg ATTRIBUTE_UNUSED;
+     segT     seg;
 {
   valueT value;
   char * where;
@@ -2455,7 +2452,6 @@ v850_fix_adjustable (fixP)
   if (S_IS_EXTERN (fixP->fx_addsy))
     return 0;
   
-  /* Similarly for weak symbols.  */
   if (S_IS_WEAK (fixP->fx_addsy))
     return 0;
   
