@@ -1,6 +1,5 @@
 /* tc-z8k.c -- Assemble code for the Zilog Z800n
-   Copyright (C) 1992, 93, 94, 95, 96, 97, 98, 99, 2000
-   Free Software Foundation.
+   Copyright (C) 1992, 93, 94, 95, 96, 97, 98, 1999 Free Software Foundation.
 
    This file is part of GAS, the GNU Assembler.
 
@@ -32,9 +31,12 @@
 #include "bfd.h"
 #include <ctype.h>
 
-const char comment_chars[] = "!";
-const char line_comment_chars[] = "#";
-const char line_separator_chars[] = ";";
+const char comment_chars[] =
+{'!', 0};
+const char line_separator_chars[] =
+{';', 0};
+const char line_comment_chars[] =
+{'#', 0};
 
 extern int machine;
 extern int coff_flags;
@@ -221,9 +223,9 @@ int the_flags;
 int the_interrupt;
 
 char *
-whatreg (reg, src)
-     int *reg;
-     char *src;
+DEFUN (whatreg, (reg, src),
+       int *reg AND
+       char *src)
 {
   if (isdigit (src[1]))
     {
@@ -253,14 +255,12 @@ whatreg (reg, src)
 
   */
 
-/* Try to parse a reg name.  Return a pointer to the first character
-   in SRC after the reg name.  */
-
+/* try and parse a reg name, returns number of chars consumed */
 char *
-parse_reg (src, mode, reg)
-     char *src;
-     int *mode;
-     unsigned int *reg;
+DEFUN (parse_reg, (src, mode, reg),
+       char *src AND
+       int *mode AND
+       unsigned int *reg)
 {
   char *res = 0;
   char regno;
@@ -328,9 +328,9 @@ parse_reg (src, mode, reg)
 }
 
 char *
-parse_exp (s, op)
-     char *s;
-     expressionS *op;
+DEFUN (parse_exp, (s, op),
+       char *s AND
+       expressionS * op)
 {
   char *save = input_line_pointer;
   char *new;
@@ -363,9 +363,9 @@ parse_exp (s, op)
 
 static
 char *
-checkfor (ptr, what)
-     char *ptr;
-     char what;
+DEFUN (checkfor, (ptr, what),
+       char *ptr AND
+       char what)
 {
   if (*ptr == what)
     ptr++;
@@ -378,9 +378,9 @@ checkfor (ptr, what)
 
 /* Make sure the mode supplied is the size of a word */
 static void
-regword (mode, string)
-     int mode;
-     char *string;
+DEFUN (regword, (mode, string),
+       int mode AND
+       char *string)
 {
   int ok;
 
@@ -393,9 +393,9 @@ regword (mode, string)
 
 /* Make sure the mode supplied is the size of an address */
 static void
-regaddr (mode, string)
-     int mode;
-     char *string;
+DEFUN (regaddr, (mode, string),
+       int mode AND
+       char *string)
 {
   int ok;
 
@@ -426,10 +426,10 @@ struct ctrl_names ctrl_table[] =
 };
    
 static void
-get_ctrl_operand (ptr, mode, dst)
-     char **ptr;
-     struct z8k_op *mode;
-     unsigned int dst;
+DEFUN (get_ctrl_operand, (ptr, mode, dst),
+       char **ptr AND
+       struct z8k_op *mode AND
+       unsigned int dst)
 {
   char *src = *ptr;
   int r;
@@ -476,10 +476,10 @@ struct flag_names flag_table[] =
 };
 
 static void
-get_flags_operand (ptr, mode, dst)
-     char **ptr;
-     struct z8k_op *mode;
-     unsigned int dst;
+DEFUN (get_flags_operand, (ptr, mode, dst),
+       char **ptr AND
+       struct z8k_op *mode AND
+       unsigned int dst)
 {
   char *src = *ptr;
   int r;
@@ -530,10 +530,10 @@ struct interrupt_names intr_table[] =
 };
 
 static void
-get_interrupt_operand (ptr, mode, dst)
-     char **ptr;
-     struct z8k_op *mode;
-     unsigned int dst;
+DEFUN (get_interrupt_operand, (ptr, mode, dst),
+       char **ptr AND
+       struct z8k_op *mode AND
+       unsigned int dst)
 {
   char *src = *ptr;
   int r;
@@ -596,10 +596,10 @@ struct cc_names table[] =
 };
 
 static void
-get_cc_operand (ptr, mode, dst)
-     char **ptr;
-     struct z8k_op *mode;
-     unsigned int dst;
+DEFUN (get_cc_operand, (ptr, mode, dst),
+       char **ptr AND
+       struct z8k_op *mode AND
+       unsigned int dst)
 {
   char *src = *ptr;
   int r;
@@ -846,9 +846,9 @@ char *savptr;
 
 static
 opcode_entry_type *
-get_specific (opcode, operands)
-     opcode_entry_type *opcode;
-     op_type *operands;
+DEFUN (get_specific, (opcode, operands),
+       opcode_entry_type * opcode AND
+       op_type * operands)
 
 {
   opcode_entry_type *this_try = opcode;
@@ -929,10 +929,10 @@ get_specific (opcode, operands)
 }
 
 static void
-check_operand (operand, width, string)
-     struct z8k_op *operand;
-     unsigned int width;
-     char *string;
+DEFUN (check_operand, (operand, width, string),
+       struct z8k_op *operand AND
+       unsigned int width AND
+       char *string)
 {
   if (operand->exp.X_add_symbol == 0
       && operand->exp.X_op_symbol == 0)
@@ -953,10 +953,10 @@ check_operand (operand, width, string)
 static char buffer[20];
 
 static void
-newfix (ptr, type, operand)
-     int ptr;
-     int type;
-     expressionS *operand;
+DEFUN (newfix, (ptr, type, operand),
+       int ptr AND
+       int type AND
+       expressionS * operand)
 {
   if (operand->X_add_symbol
       || operand->X_op_symbol
@@ -972,11 +972,11 @@ newfix (ptr, type, operand)
 }
 
 static char *
-apply_fix (ptr, type, operand, size)
-     char *ptr;
-     int type;
-     expressionS *operand;
-     int size;
+DEFUN (apply_fix, (ptr, type, operand, size),
+       char *ptr AND
+       int type AND
+       expressionS * operand AND
+       int size)
 {
   int n = operand->X_add_number;
 
@@ -1187,12 +1187,13 @@ top:;
 }
 
 /* This is the guts of the machine-dependent assembler.  STR points to a
-   machine dependent instruction.  This function is supposed to emit
-   the frags/bytes it assembles to.  */
+   machine dependent instruction.  This funciton is supposed to emit
+   the frags/bytes it assembles to.
+   */
 
 void
-md_assemble (str)
-     char *str;
+DEFUN (md_assemble, (str),
+       char *str)
 {
   char *op_start;
   char *op_end;
@@ -1283,22 +1284,22 @@ md_assemble (str)
 }
 
 void
-tc_crawl_symbol_chain (headers)
-     object_headers *headers;
+DEFUN (tc_crawl_symbol_chain, (headers),
+       object_headers * headers)
 {
   printf (_("call to tc_crawl_symbol_chain \n"));
 }
 
 symbolS *
-md_undefined_symbol (name)
-     char *name;
+DEFUN (md_undefined_symbol, (name),
+       char *name)
 {
   return 0;
 }
 
 void
-tc_headers_hook (headers)
-     object_headers *headers;
+DEFUN (tc_headers_hook, (headers),
+       object_headers * headers)
 {
   printf (_("call to tc_headers_hook \n"));
 }
@@ -1426,9 +1427,9 @@ md_convert_frag (headers, seg, fragP)
 }
 
 valueT
-md_section_align (seg, size)
-     segT seg;
-     valueT size;
+DEFUN (md_section_align, (seg, size),
+       segT seg AND
+       valueT size)
 {
   return ((size + (1 << section_alignment[(int) seg]) - 1) & (-1 << section_alignment[(int) seg]));
 
@@ -1503,10 +1504,10 @@ md_estimate_size_before_relax (fragP, segment_type)
 /* Put number into target byte order */
 
 void
-md_number_to_chars (ptr, use, nbytes)
-     char *ptr;
-     valueT use;
-     int nbytes;
+DEFUN (md_number_to_chars, (ptr, use, nbytes),
+       char *ptr AND
+       valueT use AND
+       int nbytes)
 {
   number_to_chars_bigendian (ptr, use, nbytes);
 }
