@@ -1,23 +1,22 @@
 
-/*  A Bison parser, made from ./config/m68k-parse.y
- by  GNU Bison version 1.25
-  */
+/*  A Bison parser, made from m68k-parse.y
+    by GNU Bison version 1.28  */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
-#define	DR	258
-#define	AR	259
-#define	FPR	260
-#define	FPCR	261
-#define	LPC	262
-#define	ZAR	263
-#define	ZDR	264
-#define	LZPC	265
-#define	CREG	266
-#define	INDEXREG	267
-#define	EXPR	268
+#define	DR	257
+#define	AR	258
+#define	FPR	259
+#define	FPCR	260
+#define	LPC	261
+#define	ZAR	262
+#define	ZDR	263
+#define	LZPC	264
+#define	CREG	265
+#define	INDEXREG	266
+#define	EXPR	267
 
-#line 27 "./config/m68k-parse.y"
+#line 27 "m68k-parse.y"
 
 
 #include "as.h"
@@ -83,7 +82,7 @@ static void yyerror PARAMS ((const char *));
 static struct m68k_op *op;
 
 
-#line 93 "./config/m68k-parse.y"
+#line 93 "m68k-parse.y"
 typedef union
 {
   struct m68k_indexreg indexreg;
@@ -106,7 +105,7 @@ typedef union
 #define	YYFLAG		-32768
 #define	YYNTBASE	25
 
-#define YYTRANSLATE(x) ((unsigned)(x) <= 268 ? yytranslate[x] : 44)
+#define YYTRANSLATE(x) ((unsigned)(x) <= 267 ? yytranslate[x] : 44)
 
 static const char yytranslate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -134,8 +133,8 @@ static const char yytranslate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
-     2,     2,     2,     2,     2,     1,     2,     3,     4,     5,
-     6,     7,     8,     9,    10,    11,    12,    13
+     2,     2,     2,     2,     2,     1,     3,     4,     5,     6,
+     7,     8,     9,    10,    11,    12,    13
 };
 
 #if YYDEBUG != 0
@@ -346,7 +345,8 @@ static const short yycheck[] = {    58,
     16,     0,    17,    17,    17,    17,    17
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/usr/lib/bison.simple"
+#line 3 "/usr/share/misc/bison.simple"
+/* This file comes from bison-1.28.  */
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -363,47 +363,67 @@ static const short yycheck[] = {    58,
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
    This special exception was added by the Free Software Foundation
    in version 1.24 of Bison.  */
 
-#ifndef alloca
-#ifdef __GNUC__
-#define alloca __builtin_alloca
-#else /* not GNU C.  */
-#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi)
-#include <alloca.h>
-#else /* not sparc */
-#if defined (MSDOS) && !defined (__TURBOC__)
-#include <malloc.h>
-#else /* not MSDOS, or __TURBOC__ */
-#if defined(_AIX)
-#include <malloc.h>
- #pragma alloca
-#else /* not MSDOS, __TURBOC__, or _AIX */
-#ifdef __hpux
-#ifdef __cplusplus
-extern "C" {
-void *alloca (unsigned int);
-};
-#else /* not __cplusplus */
-void *alloca ();
-#endif /* not __cplusplus */
-#endif /* __hpux */
-#endif /* not _AIX */
-#endif /* not MSDOS, or __TURBOC__ */
-#endif /* not sparc.  */
-#endif /* not GNU C.  */
-#endif /* alloca not defined.  */
-
 /* This is the parser code that is written into each bison parser
   when the %semantic_parser declaration is not specified in the grammar.
   It was written by Richard Stallman by simplifying the hairy parser
   used when %semantic_parser is specified.  */
 
+#ifndef YYSTACK_USE_ALLOCA
+#ifdef alloca
+#define YYSTACK_USE_ALLOCA
+#else /* alloca not defined */
+#ifdef __GNUC__
+#define YYSTACK_USE_ALLOCA
+#define alloca __builtin_alloca
+#else /* not GNU C.  */
+#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi) || (defined (__sun) && defined (__i386))
+#define YYSTACK_USE_ALLOCA
+#include <alloca.h>
+#else /* not sparc */
+/* We think this test detects Watcom and Microsoft C.  */
+/* This used to test MSDOS, but that is a bad idea
+   since that symbol is in the user namespace.  */
+#if (defined (_MSDOS) || defined (_MSDOS_)) && !defined (__TURBOC__)
+#if 0 /* No need for malloc.h, which pollutes the namespace;
+	 instead, just don't use alloca.  */
+#include <malloc.h>
+#endif
+#else /* not MSDOS, or __TURBOC__ */
+#if defined(_AIX)
+/* I don't know what this was needed for, but it pollutes the namespace.
+   So I turned it off.   rms, 2 May 1997.  */
+/* #include <malloc.h>  */
+ #pragma alloca
+#define YYSTACK_USE_ALLOCA
+#else /* not MSDOS, or __TURBOC__, or _AIX */
+#if 0
+#ifdef __hpux /* haible@ilog.fr says this works for HPUX 9.05 and up,
+		 and on HPUX 10.  Eventually we can turn this on.  */
+#define YYSTACK_USE_ALLOCA
+#define alloca __builtin_alloca
+#endif /* __hpux */
+#endif
+#endif /* not _AIX */
+#endif /* not MSDOS, or __TURBOC__ */
+#endif /* not sparc */
+#endif /* not GNU C */
+#endif /* alloca not defined */
+#endif /* YYSTACK_USE_ALLOCA not defined */
+
+#ifdef YYSTACK_USE_ALLOCA
+#define YYSTACK_ALLOC alloca
+#else
+#define YYSTACK_ALLOC malloc
+#endif
+
 /* Note: there must be only one dollar sign in this file.
    It is replaced by the list of actions, each action
    as one case of the switch.  */
@@ -412,8 +432,8 @@ void *alloca ();
 #define yyclearin	(yychar = YYEMPTY)
 #define YYEMPTY		-2
 #define YYEOF		0
-#define YYACCEPT	return(0)
-#define YYABORT 	return(1)
+#define YYACCEPT	goto yyacceptlab
+#define YYABORT 	goto yyabortlab
 #define YYERROR		goto yyerrlab1
 /* Like YYERROR except do call yyerror.
    This remains here temporarily to ease the
@@ -494,12 +514,12 @@ int yydebug;			/*  nonzero means print parse trace	*/
 #ifndef YYMAXDEPTH
 #define YYMAXDEPTH 10000
 #endif
-
-/* Prevent warning if -Wstrict-prototypes.  */
-#ifdef __GNUC__
-int yyparse (void);
-#endif
 
+/* Define __yy_memcpy.  Note that the size argument
+   should be passed with type unsigned int, because that is what the non-GCC
+   definitions require.  With GCC, __builtin_memcpy takes an arg
+   of type size_t, but it can handle unsigned int.  */
+
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
 #define __yy_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
 #else				/* not GNU C or C++ */
@@ -511,7 +531,7 @@ static void
 __yy_memcpy (to, from, count)
      char *to;
      char *from;
-     int count;
+     unsigned int count;
 {
   register char *f = from;
   register char *t = to;
@@ -526,10 +546,10 @@ __yy_memcpy (to, from, count)
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__yy_memcpy (char *to, char *from, int count)
+__yy_memcpy (char *to, char *from, unsigned int count)
 {
-  register char *f = from;
   register char *t = to;
+  register char *f = from;
   register int i = count;
 
   while (i-- > 0)
@@ -539,7 +559,7 @@ __yy_memcpy (char *to, char *from, int count)
 #endif
 #endif
 
-#line 196 "/usr/lib/bison.simple"
+#line 217 "/usr/share/misc/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into yyparse.  The argument should have type void *.
@@ -560,6 +580,15 @@ __yy_memcpy (char *to, char *from, int count)
 #define YYPARSE_PARAM_DECL
 #endif /* not YYPARSE_PARAM */
 
+/* Prevent warning if -Wstrict-prototypes.  */
+#ifdef __GNUC__
+#ifdef YYPARSE_PARAM
+int yyparse (void *);
+#else
+int yyparse (void);
+#endif
+#endif
+
 int
 yyparse(YYPARSE_PARAM_ARG)
      YYPARSE_PARAM_DECL
@@ -588,6 +617,7 @@ yyparse(YYPARSE_PARAM_ARG)
 #endif
 
   int yystacksize = YYINITDEPTH;
+  int yyfree_stacks = 0;
 
 #ifdef YYPURE
   int yychar;
@@ -672,18 +702,32 @@ yynewstate:
       if (yystacksize >= YYMAXDEPTH)
 	{
 	  yyerror("parser stack overflow");
+	  if (yyfree_stacks)
+	    {
+	      free (yyss);
+	      free (yyvs);
+#ifdef YYLSP_NEEDED
+	      free (yyls);
+#endif
+	    }
 	  return 2;
 	}
       yystacksize *= 2;
       if (yystacksize > YYMAXDEPTH)
 	yystacksize = YYMAXDEPTH;
-      yyss = (short *) alloca (yystacksize * sizeof (*yyssp));
-      __yy_memcpy ((char *)yyss, (char *)yyss1, size * sizeof (*yyssp));
-      yyvs = (YYSTYPE *) alloca (yystacksize * sizeof (*yyvsp));
-      __yy_memcpy ((char *)yyvs, (char *)yyvs1, size * sizeof (*yyvsp));
+#ifndef YYSTACK_USE_ALLOCA
+      yyfree_stacks = 1;
+#endif
+      yyss = (short *) YYSTACK_ALLOC (yystacksize * sizeof (*yyssp));
+      __yy_memcpy ((char *)yyss, (char *)yyss1,
+		   size * (unsigned int) sizeof (*yyssp));
+      yyvs = (YYSTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yyvsp));
+      __yy_memcpy ((char *)yyvs, (char *)yyvs1,
+		   size * (unsigned int) sizeof (*yyvsp));
 #ifdef YYLSP_NEEDED
-      yyls = (YYLTYPE *) alloca (yystacksize * sizeof (*yylsp));
-      __yy_memcpy ((char *)yyls, (char *)yyls1, size * sizeof (*yylsp));
+      yyls = (YYLTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yylsp));
+      __yy_memcpy ((char *)yyls, (char *)yyls1,
+		   size * (unsigned int) sizeof (*yylsp));
 #endif
 #endif /* no yyoverflow */
 
@@ -844,91 +888,91 @@ yyreduce:
   switch (yyn) {
 
 case 4:
-#line 126 "./config/m68k-parse.y"
+#line 126 "m68k-parse.y"
 {
 		  op->mode = DREG;
 		  op->reg = yyvsp[0].reg;
 		;
     break;}
 case 5:
-#line 131 "./config/m68k-parse.y"
+#line 131 "m68k-parse.y"
 {
 		  op->mode = AREG;
 		  op->reg = yyvsp[0].reg;
 		;
     break;}
 case 6:
-#line 136 "./config/m68k-parse.y"
+#line 136 "m68k-parse.y"
 {
 		  op->mode = FPREG;
 		  op->reg = yyvsp[0].reg;
 		;
     break;}
 case 7:
-#line 141 "./config/m68k-parse.y"
+#line 141 "m68k-parse.y"
 {
 		  op->mode = CONTROL;
 		  op->reg = yyvsp[0].reg;
 		;
     break;}
 case 8:
-#line 146 "./config/m68k-parse.y"
+#line 146 "m68k-parse.y"
 {
 		  op->mode = CONTROL;
 		  op->reg = yyvsp[0].reg;
 		;
     break;}
 case 9:
-#line 151 "./config/m68k-parse.y"
+#line 151 "m68k-parse.y"
 {
 		  op->mode = ABSL;
 		  op->disp = yyvsp[0].exp;
 		;
     break;}
 case 10:
-#line 156 "./config/m68k-parse.y"
+#line 156 "m68k-parse.y"
 {
 		  op->mode = IMMED;
 		  op->disp = yyvsp[0].exp;
 		;
     break;}
 case 11:
-#line 161 "./config/m68k-parse.y"
+#line 161 "m68k-parse.y"
 {
 		  op->mode = IMMED;
 		  op->disp = yyvsp[0].exp;
 		;
     break;}
 case 12:
-#line 166 "./config/m68k-parse.y"
+#line 166 "m68k-parse.y"
 {
 		  op->mode = REGLST;
 		  op->mask = yyvsp[0].mask;
 		;
     break;}
 case 13:
-#line 179 "./config/m68k-parse.y"
+#line 179 "m68k-parse.y"
 {
 		  op->mode = AINDR;
 		  op->reg = yyvsp[-1].reg;
 		;
     break;}
 case 14:
-#line 184 "./config/m68k-parse.y"
+#line 184 "m68k-parse.y"
 {
 		  op->mode = AINC;
 		  op->reg = yyvsp[-2].reg;
 		;
     break;}
 case 15:
-#line 189 "./config/m68k-parse.y"
+#line 189 "m68k-parse.y"
 {
 		  op->mode = ADEC;
 		  op->reg = yyvsp[-1].reg;
 		;
     break;}
 case 16:
-#line 194 "./config/m68k-parse.y"
+#line 194 "m68k-parse.y"
 {
 		  op->reg = yyvsp[-1].reg;
 		  op->disp = yyvsp[-3].exp;
@@ -940,7 +984,7 @@ case 16:
 		;
     break;}
 case 17:
-#line 204 "./config/m68k-parse.y"
+#line 204 "m68k-parse.y"
 {
 		  op->reg = yyvsp[-3].reg;
 		  op->disp = yyvsp[-1].exp;
@@ -952,7 +996,7 @@ case 17:
 		;
     break;}
 case 18:
-#line 214 "./config/m68k-parse.y"
+#line 214 "m68k-parse.y"
 {
 		  op->reg = yyvsp[-1].reg;
 		  op->disp = yyvsp[-3].exp;
@@ -964,28 +1008,28 @@ case 18:
 		;
     break;}
 case 19:
-#line 224 "./config/m68k-parse.y"
+#line 224 "m68k-parse.y"
 {
 		  op->mode = DISP;
 		  op->reg = yyvsp[-1].reg;
 		;
     break;}
 case 20:
-#line 229 "./config/m68k-parse.y"
+#line 229 "m68k-parse.y"
 {
 		  op->mode = BASE;
 		  op->reg = yyvsp[-1].reg;
 		;
     break;}
 case 21:
-#line 234 "./config/m68k-parse.y"
+#line 234 "m68k-parse.y"
 {
 		  op->mode = BASE;
 		  op->reg = yyvsp[-1].reg;
 		;
     break;}
 case 22:
-#line 239 "./config/m68k-parse.y"
+#line 239 "m68k-parse.y"
 {
 		  op->mode = BASE;
 		  op->reg = yyvsp[-3].reg;
@@ -994,10 +1038,10 @@ case 22:
 		;
     break;}
 case 23:
-#line 246 "./config/m68k-parse.y"
+#line 246 "m68k-parse.y"
 {
 		  if (yyvsp[-3].reg == PC || yyvsp[-3].reg == ZPC)
-		    yyerror ("syntax error");
+		    yyerror (_("syntax error"));
 		  op->mode = BASE;
 		  op->reg = yyvsp[-1].reg;
 		  op->disp = yyvsp[-5].exp;
@@ -1007,7 +1051,7 @@ case 23:
 		;
     break;}
 case 24:
-#line 257 "./config/m68k-parse.y"
+#line 257 "m68k-parse.y"
 {
 		  op->mode = BASE;
 		  op->reg = yyvsp[-1].reg;
@@ -1016,7 +1060,7 @@ case 24:
 		;
     break;}
 case 25:
-#line 264 "./config/m68k-parse.y"
+#line 264 "m68k-parse.y"
 {
 		  op->mode = BASE;
 		  op->disp = yyvsp[-1].exp;
@@ -1024,7 +1068,7 @@ case 25:
 		;
     break;}
 case 26:
-#line 270 "./config/m68k-parse.y"
+#line 270 "m68k-parse.y"
 {
 		  op->mode = BASE;
 		  op->reg = yyvsp[-3].reg;
@@ -1033,7 +1077,7 @@ case 26:
 		;
     break;}
 case 27:
-#line 277 "./config/m68k-parse.y"
+#line 277 "m68k-parse.y"
 {
 		  op->mode = BASE;
 		  op->reg = yyvsp[-3].reg;
@@ -1041,10 +1085,10 @@ case 27:
 		;
     break;}
 case 28:
-#line 283 "./config/m68k-parse.y"
+#line 283 "m68k-parse.y"
 {
 		  if (yyvsp[-3].reg == PC || yyvsp[-3].reg == ZPC)
-		    yyerror ("syntax error");
+		    yyerror (_("syntax error"));
 		  op->mode = BASE;
 		  op->reg = yyvsp[-1].reg;
 		  op->disp = yyvsp[-5].exp;
@@ -1054,10 +1098,10 @@ case 28:
 		;
     break;}
 case 29:
-#line 294 "./config/m68k-parse.y"
+#line 294 "m68k-parse.y"
 {
 		  if (yyvsp[-3].reg == PC || yyvsp[-3].reg == ZPC)
-		    yyerror ("syntax error");
+		    yyerror (_("syntax error"));
 		  op->mode = BASE;
 		  op->reg = yyvsp[-1].reg;
 		  op->index.reg = yyvsp[-3].reg;
@@ -1066,7 +1110,7 @@ case 29:
 		;
     break;}
 case 30:
-#line 304 "./config/m68k-parse.y"
+#line 304 "m68k-parse.y"
 {
 		  op->mode = BASE;
 		  op->reg = yyvsp[-1].reg;
@@ -1075,7 +1119,7 @@ case 30:
 		;
     break;}
 case 31:
-#line 311 "./config/m68k-parse.y"
+#line 311 "m68k-parse.y"
 {
 		  op->mode = BASE;
 		  op->reg = yyvsp[-1].reg;
@@ -1083,7 +1127,7 @@ case 31:
 		;
     break;}
 case 32:
-#line 317 "./config/m68k-parse.y"
+#line 317 "m68k-parse.y"
 {
 		  op->mode = POST;
 		  op->reg = yyvsp[-5].reg;
@@ -1093,7 +1137,7 @@ case 32:
 		;
     break;}
 case 33:
-#line 325 "./config/m68k-parse.y"
+#line 325 "m68k-parse.y"
 {
 		  op->mode = POST;
 		  op->reg = yyvsp[-3].reg;
@@ -1102,7 +1146,7 @@ case 33:
 		;
     break;}
 case 34:
-#line 332 "./config/m68k-parse.y"
+#line 332 "m68k-parse.y"
 {
 		  op->mode = POST;
 		  op->reg = yyvsp[-5].reg;
@@ -1111,7 +1155,7 @@ case 34:
 		;
     break;}
 case 35:
-#line 339 "./config/m68k-parse.y"
+#line 339 "m68k-parse.y"
 {
 		  op->mode = POST;
 		  op->reg = yyvsp[-3].reg;
@@ -1119,7 +1163,7 @@ case 35:
 		;
     break;}
 case 36:
-#line 345 "./config/m68k-parse.y"
+#line 345 "m68k-parse.y"
 {
 		  op->mode = PRE;
 		  op->reg = yyvsp[-5].reg;
@@ -1129,7 +1173,7 @@ case 36:
 		;
     break;}
 case 37:
-#line 353 "./config/m68k-parse.y"
+#line 353 "m68k-parse.y"
 {
 		  op->mode = PRE;
 		  op->reg = yyvsp[-5].reg;
@@ -1138,10 +1182,10 @@ case 37:
 		;
     break;}
 case 38:
-#line 360 "./config/m68k-parse.y"
+#line 360 "m68k-parse.y"
 {
 		  if (yyvsp[-5].reg == PC || yyvsp[-5].reg == ZPC)
-		    yyerror ("syntax error");
+		    yyerror (_("syntax error"));
 		  op->mode = PRE;
 		  op->reg = yyvsp[-3].reg;
 		  op->disp = yyvsp[-7].exp;
@@ -1152,10 +1196,10 @@ case 38:
 		;
     break;}
 case 39:
-#line 372 "./config/m68k-parse.y"
+#line 372 "m68k-parse.y"
 {
 		  if (yyvsp[-5].reg == PC || yyvsp[-5].reg == ZPC)
-		    yyerror ("syntax error");
+		    yyerror (_("syntax error"));
 		  op->mode = PRE;
 		  op->reg = yyvsp[-3].reg;
 		  op->index.reg = yyvsp[-5].reg;
@@ -1165,7 +1209,7 @@ case 39:
 		;
     break;}
 case 40:
-#line 383 "./config/m68k-parse.y"
+#line 383 "m68k-parse.y"
 {
 		  op->mode = PRE;
 		  op->reg = yyvsp[-3].reg;
@@ -1175,37 +1219,37 @@ case 40:
 		;
     break;}
 case 41:
-#line 396 "./config/m68k-parse.y"
+#line 396 "m68k-parse.y"
 {
 		  /* We use optzapc to avoid a shift/reduce conflict.  */
 		  if (yyvsp[-1].reg < ADDR0 || yyvsp[-1].reg > ADDR7)
-		    yyerror ("syntax error");
+		    yyerror (_("syntax error"));
 		  op->mode = AINDR;
 		  op->reg = yyvsp[-1].reg;
 		;
     break;}
 case 42:
-#line 404 "./config/m68k-parse.y"
+#line 404 "m68k-parse.y"
 {
 		  /* We use optzapc to avoid a shift/reduce conflict.  */
 		  if (yyvsp[-2].reg < ADDR0 || yyvsp[-2].reg > ADDR7)
-		    yyerror ("syntax error");
+		    yyerror (_("syntax error"));
 		  op->mode = AINC;
 		  op->reg = yyvsp[-2].reg;
 		;
     break;}
 case 43:
-#line 412 "./config/m68k-parse.y"
+#line 412 "m68k-parse.y"
 {
 		  /* We use optzapc to avoid a shift/reduce conflict.  */
 		  if (yyvsp[-2].reg < ADDR0 || yyvsp[-2].reg > ADDR7)
-		    yyerror ("syntax error");
+		    yyerror (_("syntax error"));
 		  op->mode = ADEC;
 		  op->reg = yyvsp[-2].reg;
 		;
     break;}
 case 44:
-#line 420 "./config/m68k-parse.y"
+#line 420 "m68k-parse.y"
 {
 		  op->reg = yyvsp[-4].reg;
 		  op->disp = yyvsp[-1].exp;
@@ -1217,7 +1261,7 @@ case 44:
 		;
     break;}
 case 45:
-#line 430 "./config/m68k-parse.y"
+#line 430 "m68k-parse.y"
 {
 		  op->mode = BASE;
 		  op->reg = yyvsp[-5].reg;
@@ -1226,7 +1270,7 @@ case 45:
 		;
     break;}
 case 46:
-#line 437 "./config/m68k-parse.y"
+#line 437 "m68k-parse.y"
 {
 		  op->mode = POST;
 		  op->reg = yyvsp[-9].reg;
@@ -1236,7 +1280,7 @@ case 46:
 		;
     break;}
 case 47:
-#line 445 "./config/m68k-parse.y"
+#line 445 "m68k-parse.y"
 {
 		  op->mode = POST;
 		  op->reg = yyvsp[-8].reg;
@@ -1245,7 +1289,7 @@ case 47:
 		;
     break;}
 case 48:
-#line 452 "./config/m68k-parse.y"
+#line 452 "m68k-parse.y"
 {
 		  op->mode = PRE;
 		  op->reg = yyvsp[-9].reg;
@@ -1255,7 +1299,7 @@ case 48:
 		;
     break;}
 case 50:
-#line 467 "./config/m68k-parse.y"
+#line 467 "m68k-parse.y"
 {
 		  yyval.indexreg.reg = yyvsp[0].reg;
 		  yyval.indexreg.size = SIZE_UNSPEC;
@@ -1263,7 +1307,7 @@ case 50:
 		;
     break;}
 case 52:
-#line 481 "./config/m68k-parse.y"
+#line 481 "m68k-parse.y"
 {
 		  yyval.indexreg.reg = yyvsp[0].reg;
 		  yyval.indexreg.size = SIZE_UNSPEC;
@@ -1271,81 +1315,81 @@ case 52:
 		;
     break;}
 case 63:
-#line 524 "./config/m68k-parse.y"
+#line 524 "m68k-parse.y"
 {
 		  yyval.reg = ZADDR0;
 		;
     break;}
 case 67:
-#line 541 "./config/m68k-parse.y"
+#line 541 "m68k-parse.y"
 {
 		  yyval.reg = ZADDR0;
 		;
     break;}
 case 68:
-#line 545 "./config/m68k-parse.y"
+#line 545 "m68k-parse.y"
 {
 		  yyval.reg = yyvsp[0].reg;
 		;
     break;}
 case 69:
-#line 554 "./config/m68k-parse.y"
+#line 554 "m68k-parse.y"
 {
 		  yyval.exp.exp.X_op = O_absent;
 		  yyval.exp.size = SIZE_UNSPEC;
 		;
     break;}
 case 70:
-#line 559 "./config/m68k-parse.y"
+#line 559 "m68k-parse.y"
 {
 		  yyval.exp = yyvsp[0].exp;
 		;
     break;}
 case 71:
-#line 568 "./config/m68k-parse.y"
+#line 568 "m68k-parse.y"
 {
 		  yyval.exp.exp.X_op = O_absent;
 		  yyval.exp.size = SIZE_UNSPEC;
 		;
     break;}
 case 72:
-#line 573 "./config/m68k-parse.y"
+#line 573 "m68k-parse.y"
 {
 		  yyval.exp = yyvsp[-1].exp;
 		;
     break;}
 case 74:
-#line 583 "./config/m68k-parse.y"
+#line 583 "m68k-parse.y"
 {
 		  yyval.mask = yyvsp[-2].mask | yyvsp[0].mask;
 		;
     break;}
 case 75:
-#line 587 "./config/m68k-parse.y"
+#line 587 "m68k-parse.y"
 {
 		  yyval.mask = (1 << yyvsp[-2].onereg) | yyvsp[0].mask;
 		;
     break;}
 case 76:
-#line 599 "./config/m68k-parse.y"
+#line 599 "m68k-parse.y"
 {
 		  yyval.mask = 1 << yyvsp[0].onereg;
 		;
     break;}
 case 78:
-#line 604 "./config/m68k-parse.y"
+#line 604 "m68k-parse.y"
 {
 		  yyval.mask = yyvsp[-2].mask | yyvsp[0].mask;
 		;
     break;}
 case 79:
-#line 608 "./config/m68k-parse.y"
+#line 608 "m68k-parse.y"
 {
 		  yyval.mask = (1 << yyvsp[-2].onereg) | yyvsp[0].mask;
 		;
     break;}
 case 80:
-#line 615 "./config/m68k-parse.y"
+#line 615 "m68k-parse.y"
 {
 		  if (yyvsp[-2].onereg <= yyvsp[0].onereg)
 		    yyval.mask = (1 << (yyvsp[0].onereg + 1)) - 1 - ((1 << yyvsp[-2].onereg) - 1);
@@ -1354,25 +1398,25 @@ case 80:
 		;
     break;}
 case 81:
-#line 625 "./config/m68k-parse.y"
+#line 625 "m68k-parse.y"
 {
 		  yyval.onereg = yyvsp[0].reg - DATA0;
 		;
     break;}
 case 82:
-#line 629 "./config/m68k-parse.y"
+#line 629 "m68k-parse.y"
 {
 		  yyval.onereg = yyvsp[0].reg - ADDR0 + 8;
 		;
     break;}
 case 83:
-#line 633 "./config/m68k-parse.y"
+#line 633 "m68k-parse.y"
 {
 		  yyval.onereg = yyvsp[0].reg - FP0 + 16;
 		;
     break;}
 case 84:
-#line 637 "./config/m68k-parse.y"
+#line 637 "m68k-parse.y"
 {
 		  if (yyvsp[0].reg == FPI)
 		    yyval.onereg = 24;
@@ -1384,7 +1428,7 @@ case 84:
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 498 "/usr/lib/bison.simple"
+#line 543 "/usr/share/misc/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1579,8 +1623,32 @@ yyerrhandle:
 
   yystate = yyn;
   goto yynewstate;
+
+ yyacceptlab:
+  /* YYACCEPT comes here.  */
+  if (yyfree_stacks)
+    {
+      free (yyss);
+      free (yyvs);
+#ifdef YYLSP_NEEDED
+      free (yyls);
+#endif
+    }
+  return 0;
+
+ yyabortlab:
+  /* YYABORT comes here.  */
+  if (yyfree_stacks)
+    {
+      free (yyss);
+      free (yyvs);
+#ifdef YYLSP_NEEDED
+      free (yyls);
+#endif
+    }
+  return 1;
 }
-#line 647 "./config/m68k-parse.y"
+#line 647 "m68k-parse.y"
 
 
 /* The string to parse is stored here, and modified by yylex.  */
@@ -1808,7 +1876,7 @@ yylex ()
 	      ++s;
 	      break;
 	    default:
-	      yyerror ("illegal size specification");
+	      yyerror (_("illegal size specification"));
 	      yylval.indexreg.size = SIZE_UNSPEC;
 	      break;
 	    }
@@ -1829,7 +1897,7 @@ yylex ()
 	  input_line_pointer = hold;
 
 	  if (scale.X_op != O_constant)
-	    yyerror ("scale specification must resolve to a number");
+	    yyerror (_("scale specification must resolve to a number"));
 	  else
 	    {
 	      switch (scale.X_add_number)
@@ -1841,7 +1909,7 @@ yylex ()
 		  yylval.indexreg.scale = scale.X_add_number;
 		  break;
 		default:
-		  yyerror ("invalid scale value");
+		  yyerror (_("invalid scale value"));
 		  break;
 		}
 	    }
