@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1983 Regents of the University of California.
+ * Copyright (c) 1983, 1998 Regents of the University of California.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms are permitted
@@ -18,7 +18,7 @@
  */
 #include "gprof.h"
 #include "cg_arcs.h"
-#include "core.h"
+#include "corefile.h"
 #include "hist.h"
 #include "symtab.h"
 
@@ -86,7 +86,7 @@ alpha_find_call (parent, p_lowpc, p_highpc)
       delta = (bfd_vma) core_text_space - core_text_sect->vma;
 
       sym_init (&indirect_child);
-      indirect_child.name = "<indirect child>";
+      indirect_child.name = _("<indirect child>");
       indirect_child.cg.prop.fract = 1.0;
       indirect_child.cg.cyc.head = &indirect_child;
     }
@@ -103,8 +103,9 @@ alpha_find_call (parent, p_lowpc, p_highpc)
     {
       p_highpc = s_highpc;
     }
-  DBG (CALLDEBUG, printf ("[find_call] %s: 0x%lx to 0x%lx\n",
-			  parent->name, p_lowpc, p_highpc));
+  DBG (CALLDEBUG, printf (_("[find_call] %s: 0x%lx to 0x%lx\n"),
+			  parent->name, (unsigned long) p_lowpc,
+			  (unsigned long) p_highpc));
   for (pc = (alpha_Instruction *) (p_lowpc + delta);
        pc < (alpha_Instruction *) (p_highpc + delta);
        ++pc)
@@ -124,16 +125,17 @@ alpha_find_call (parent, p_lowpc, p_highpc)
 	      || pc->j.func == Jxx_FUNC_JSR_COROUTINE)
 	    {
 	      DBG (CALLDEBUG,
-		   printf ("[find_call] 0x%lx: jsr%s <indirect_child>\n",
-			   (bfd_vma) pc - delta,
+		   printf (_("[find_call] 0x%lx: jsr%s <indirect_child>\n"),
+			   (unsigned long) pc - delta,
 			   pc->j.func == Jxx_FUNC_JSR ? "" : "_coroutine"));
-	      arc_add (parent, &indirect_child, 0);
+	      arc_add (parent, &indirect_child, (unsigned long) 0);
 	    }
 	  break;
 
 	case OP_BSR:
 	  DBG (CALLDEBUG,
-	       printf ("[find_call] 0x%lx: bsr", (bfd_vma) pc - delta));
+	       printf (_("[find_call] 0x%lx: bsr"),
+		       (unsigned long) pc - delta));
 	  /*
 	   * Regular PC relative addressing.  Check that this is the
 	   * address of a function.  The linker sometimes redirects
@@ -146,12 +148,13 @@ alpha_find_call (parent, p_lowpc, p_highpc)
 	      child = sym_lookup (&symtab, dest_pc);
 	      DBG (CALLDEBUG,
 		   printf (" 0x%lx\t; name=%s, addr=0x%lx",
-			   dest_pc, child->name, child->addr));
+			   (unsigned long) dest_pc, child->name,
+			   (unsigned long) child->addr));
 	      if (child->addr == dest_pc || child->addr == dest_pc - 8)
 		{
 		  DBG (CALLDEBUG, printf ("\n"));
 		  /* a hit:  */
-		  arc_add (parent, child, 0);
+		  arc_add (parent, child, (unsigned long) 0);
 		  continue;
 		}
 	    }
